import typing

import android.app
import android.content
import android.net
import android.os
import java
import java.chaquopy
import java.lang
import java.util

class CarrierIdentifier(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CarrierIdentifier]] = ...
    @typing.overload
    def __init__(self, mccMnc: java.chaquopy.JavaArrayJByte, gid1: str | java.lang.String, gid2: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, mcc: str | java.lang.String, mnc: str | java.lang.String, spn: str | java.lang.String, imsi: str | java.lang.String, gid1: str | java.lang.String, gid2: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, mcc: str | java.lang.String, mnc: str | java.lang.String, spn: str | java.lang.String, imsi: str | java.lang.String, gid1: str | java.lang.String, gid2: str | java.lang.String, carrierid: int | java.jint | java.lang.Integer, specificCarrierId: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getCarrierId(self) -> int: ...
    def getGid1(self) -> str | None: ...
    def getGid2(self) -> str | None: ...
    def getImsi(self) -> str | None: ...
    def getMcc(self) -> str: ...
    def getMnc(self) -> str: ...
    def getSpecificCarrierId(self) -> int: ...
    def getSpn(self) -> str | None: ...
    def hashCode(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, out: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CarrierMessagingClientService(android.app.Service):
    def __init__(self) -> None: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...


_CarrierMessagingService__ResultCallback__T = typing.TypeVar('_CarrierMessagingService__ResultCallback__T')  # <T>
class CarrierMessagingService(android.app.Service):
    DOWNLOAD_STATUS_ERROR: typing.ClassVar[int] = ...
    DOWNLOAD_STATUS_MMS_ERROR_CONFIGURATION_ERROR: typing.ClassVar[int] = ...
    DOWNLOAD_STATUS_MMS_ERROR_DATA_DISABLED: typing.ClassVar[int] = ...
    DOWNLOAD_STATUS_MMS_ERROR_HTTP_FAILURE: typing.ClassVar[int] = ...
    DOWNLOAD_STATUS_MMS_ERROR_INACTIVE_SUBSCRIPTION: typing.ClassVar[int] = ...
    DOWNLOAD_STATUS_MMS_ERROR_INVALID_APN: typing.ClassVar[int] = ...
    DOWNLOAD_STATUS_MMS_ERROR_INVALID_SUBSCRIPTION_ID: typing.ClassVar[int] = ...
    DOWNLOAD_STATUS_MMS_ERROR_IO_ERROR: typing.ClassVar[int] = ...
    DOWNLOAD_STATUS_MMS_ERROR_MMS_DISABLED_BY_CARRIER: typing.ClassVar[int] = ...
    DOWNLOAD_STATUS_MMS_ERROR_NO_DATA_NETWORK: typing.ClassVar[int] = ...
    DOWNLOAD_STATUS_MMS_ERROR_RETRY: typing.ClassVar[int] = ...
    DOWNLOAD_STATUS_MMS_ERROR_UNABLE_CONNECT_MMS: typing.ClassVar[int] = ...
    DOWNLOAD_STATUS_MMS_ERROR_UNSPECIFIED: typing.ClassVar[int] = ...
    DOWNLOAD_STATUS_OK: typing.ClassVar[int] = ...
    DOWNLOAD_STATUS_RETRY_ON_CARRIER_NETWORK: typing.ClassVar[int] = ...
    RECEIVE_OPTIONS_DEFAULT: typing.ClassVar[int] = ...
    RECEIVE_OPTIONS_DROP: typing.ClassVar[int] = ...
    RECEIVE_OPTIONS_SKIP_NOTIFY_WHEN_CREDENTIAL_PROTECTED_STORAGE_UNAVAILABLE: typing.ClassVar[int] = ...
    SEND_FLAG_REQUEST_DELIVERY_STATUS: typing.ClassVar[int] = ...
    SEND_STATUS_ERROR: typing.ClassVar[int] = ...
    SEND_STATUS_MMS_ERROR_CONFIGURATION_ERROR: typing.ClassVar[int] = ...
    SEND_STATUS_MMS_ERROR_DATA_DISABLED: typing.ClassVar[int] = ...
    SEND_STATUS_MMS_ERROR_HTTP_FAILURE: typing.ClassVar[int] = ...
    SEND_STATUS_MMS_ERROR_INACTIVE_SUBSCRIPTION: typing.ClassVar[int] = ...
    SEND_STATUS_MMS_ERROR_INVALID_APN: typing.ClassVar[int] = ...
    SEND_STATUS_MMS_ERROR_INVALID_SUBSCRIPTION_ID: typing.ClassVar[int] = ...
    SEND_STATUS_MMS_ERROR_IO_ERROR: typing.ClassVar[int] = ...
    SEND_STATUS_MMS_ERROR_MMS_DISABLED_BY_CARRIER: typing.ClassVar[int] = ...
    SEND_STATUS_MMS_ERROR_NO_DATA_NETWORK: typing.ClassVar[int] = ...
    SEND_STATUS_MMS_ERROR_RETRY: typing.ClassVar[int] = ...
    SEND_STATUS_MMS_ERROR_UNABLE_CONNECT_MMS: typing.ClassVar[int] = ...
    SEND_STATUS_MMS_ERROR_UNSPECIFIED: typing.ClassVar[int] = ...
    SEND_STATUS_OK: typing.ClassVar[int] = ...
    SEND_STATUS_RESULT_CANCELLED: typing.ClassVar[int] = ...
    SEND_STATUS_RESULT_ENCODING_ERROR: typing.ClassVar[int] = ...
    SEND_STATUS_RESULT_ERROR_FDN_CHECK_FAILURE: typing.ClassVar[int] = ...
    SEND_STATUS_RESULT_ERROR_GENERIC_FAILURE: typing.ClassVar[int] = ...
    SEND_STATUS_RESULT_ERROR_LIMIT_EXCEEDED: typing.ClassVar[int] = ...
    SEND_STATUS_RESULT_ERROR_NO_SERVICE: typing.ClassVar[int] = ...
    SEND_STATUS_RESULT_ERROR_NULL_PDU: typing.ClassVar[int] = ...
    SEND_STATUS_RESULT_ERROR_SHORT_CODE_NEVER_ALLOWED: typing.ClassVar[int] = ...
    SEND_STATUS_RESULT_ERROR_SHORT_CODE_NOT_ALLOWED: typing.ClassVar[int] = ...
    SEND_STATUS_RESULT_INVALID_ARGUMENTS: typing.ClassVar[int] = ...
    SEND_STATUS_RESULT_INVALID_SMSC_ADDRESS: typing.ClassVar[int] = ...
    SEND_STATUS_RESULT_INVALID_SMS_FORMAT: typing.ClassVar[int] = ...
    SEND_STATUS_RESULT_INVALID_STATE: typing.ClassVar[int] = ...
    SEND_STATUS_RESULT_NETWORK_ERROR: typing.ClassVar[int] = ...
    SEND_STATUS_RESULT_NETWORK_REJECT: typing.ClassVar[int] = ...
    SEND_STATUS_RESULT_OPERATION_NOT_ALLOWED: typing.ClassVar[int] = ...
    SEND_STATUS_RESULT_REQUEST_NOT_SUPPORTED: typing.ClassVar[int] = ...
    SEND_STATUS_RESULT_SMS_BLOCKED_DURING_EMERGENCY: typing.ClassVar[int] = ...
    SEND_STATUS_RESULT_SMS_SEND_RETRY_FAILED: typing.ClassVar[int] = ...
    SEND_STATUS_RETRY_ON_CARRIER_NETWORK: typing.ClassVar[int] = ...
    SERVICE_INTERFACE: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder | None: ...
    def onDownloadMms(self, contentUri: android.net.Uri, subId: int | java.jint | java.lang.Integer, location: android.net.Uri, callback: CarrierMessagingService.ResultCallback[java.lang.Integer], /) -> None: ...
    def onFilterSms(self, pdu: MessagePdu, format: str | java.lang.String, destPort: int | java.jint | java.lang.Integer, subId: int | java.jint | java.lang.Integer, callback: CarrierMessagingService.ResultCallback[java.lang.Boolean], /) -> None: ...
    def onReceiveTextSms(self, pdu: MessagePdu, format: str | java.lang.String, destPort: int | java.jint | java.lang.Integer, subId: int | java.jint | java.lang.Integer, callback: CarrierMessagingService.ResultCallback[java.lang.Integer], /) -> None: ...
    @typing.overload
    def onSendDataSms(self, data: java.chaquopy.JavaArrayJByte, subId: int | java.jint | java.lang.Integer, destAddress: str | java.lang.String, destPort: int | java.jint | java.lang.Integer, callback: CarrierMessagingService.ResultCallback[CarrierMessagingService.SendSmsResult], /) -> None: ...
    @typing.overload
    def onSendDataSms(self, data: java.chaquopy.JavaArrayJByte, subId: int | java.jint | java.lang.Integer, destAddress: str | java.lang.String, destPort: int | java.jint | java.lang.Integer, sendSmsFlag: int | java.jint | java.lang.Integer, callback: CarrierMessagingService.ResultCallback[CarrierMessagingService.SendSmsResult], /) -> None: ...
    def onSendMms(self, pduUri: android.net.Uri, subId: int | java.jint | java.lang.Integer, location: android.net.Uri, callback: CarrierMessagingService.ResultCallback[CarrierMessagingService.SendMmsResult], /) -> None: ...
    @typing.overload
    def onSendMultipartTextSms(self, parts: java.util.List[java.lang.String], subId: int | java.jint | java.lang.Integer, destAddress: str | java.lang.String, callback: CarrierMessagingService.ResultCallback[CarrierMessagingService.SendMultipartSmsResult], /) -> None: ...
    @typing.overload
    def onSendMultipartTextSms(self, parts: java.util.List[java.lang.String], subId: int | java.jint | java.lang.Integer, destAddress: str | java.lang.String, sendSmsFlag: int | java.jint | java.lang.Integer, callback: CarrierMessagingService.ResultCallback[CarrierMessagingService.SendMultipartSmsResult], /) -> None: ...
    @typing.overload
    def onSendTextSms(self, text: str | java.lang.String, subId: int | java.jint | java.lang.Integer, destAddress: str | java.lang.String, callback: CarrierMessagingService.ResultCallback[CarrierMessagingService.SendSmsResult], /) -> None: ...
    @typing.overload
    def onSendTextSms(self, text: str | java.lang.String, subId: int | java.jint | java.lang.Integer, destAddress: str | java.lang.String, sendSmsFlag: int | java.jint | java.lang.Integer, callback: CarrierMessagingService.ResultCallback[CarrierMessagingService.SendSmsResult], /) -> None: ...

    class SendSmsResult(java.lang.Object):
        def __init__(self, sendStatus: int | java.jint | java.lang.Integer, messageRef: int | java.jint | java.lang.Integer, /) -> None: ...
        def getMessageRef(self) -> int: ...
        def getSendStatus(self) -> int: ...

    class SendMultipartSmsResult(java.lang.Object):
        def __init__(self, sendStatus: int | java.jint | java.lang.Integer, messageRefs: java.chaquopy.JavaArrayJInt, /) -> None: ...
        def getMessageRefs(self) -> java.chaquopy.JavaArrayJInt: ...
        def getSendStatus(self) -> int: ...

    class SendMmsResult(java.lang.Object):
        def __init__(self, sendStatus: int | java.jint | java.lang.Integer, sendConfPdu: java.chaquopy.JavaArrayJByte, /) -> None: ...
        def getSendConfPdu(self) -> java.chaquopy.JavaArrayJByte: ...
        def getSendStatus(self) -> int: ...
    class ResultCallback(java.lang.Object, typing.Generic[_CarrierMessagingService__ResultCallback__T]):
        def onReceiveResult(self, arg1: _CarrierMessagingService__ResultCallback__T, /) -> None: ...

class CarrierService(android.app.Service):
    CARRIER_SERVICE_INTERFACE: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    @typing.overload
    def notifyCarrierNetworkChange(self, active: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    @typing.overload
    def notifyCarrierNetworkChange(self, subscriptionId: int | java.jint | java.lang.Integer, active: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...
    @typing.overload
    def onLoadConfig(self, arg1: CarrierIdentifier, /) -> android.os.PersistableBundle | None: ...
    @typing.overload
    def onLoadConfig(self, subscriptionId: int | java.jint | java.lang.Integer, id: CarrierIdentifier, /) -> android.os.PersistableBundle | None: ...

class MessagePdu(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[MessagePdu]] = ...
    def __init__(self, pduList: java.util.List[java.chaquopy.JavaArrayJByte], /) -> None: ...
    def describeContents(self) -> int: ...
    def getPdus(self) -> java.util.List[java.chaquopy.JavaArrayJByte]: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...



import typing

import java.lang
import java.security

class LoginException(java.security.GeneralSecurityException):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, /) -> None: ...



import typing

import android.graphics
import android.os
import java
import java.chaquopy
import java.lang
import java.util

class FormEditRecord(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[FormEditRecord]] = ...
    EDIT_TYPE_CLICK: typing.ClassVar[int] = ...
    EDIT_TYPE_SET_INDICES: typing.ClassVar[int] = ...
    EDIT_TYPE_SET_TEXT: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getClickPoint(self) -> android.graphics.Point | None: ...
    def getPageNumber(self) -> int: ...
    def getSelectedIndices(self) -> java.chaquopy.JavaArrayJInt: ...
    def getText(self) -> str | None: ...
    def getType(self) -> int: ...
    def getWidgetIndex(self) -> int: ...
    def hashCode(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, type: int | java.jint | java.lang.Integer, pageNumber: int | java.jint | java.lang.Integer, widgetIndex: int | java.jint | java.lang.Integer, /) -> None: ...
        def build(self) -> FormEditRecord: ...
        def setClickPoint(self, clickPoint: android.graphics.Point, /) -> FormEditRecord.Builder: ...
        def setSelectedIndices(self, selectedIndices: java.chaquopy.JavaArrayJInt, /) -> FormEditRecord.Builder: ...
        def setText(self, text: str | java.lang.String, /) -> FormEditRecord.Builder: ...

class FormWidgetInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[FormWidgetInfo]] = ...
    WIDGET_TYPE_CHECKBOX: typing.ClassVar[int] = ...
    WIDGET_TYPE_COMBOBOX: typing.ClassVar[int] = ...
    WIDGET_TYPE_LISTBOX: typing.ClassVar[int] = ...
    WIDGET_TYPE_PUSHBUTTON: typing.ClassVar[int] = ...
    WIDGET_TYPE_RADIOBUTTON: typing.ClassVar[int] = ...
    WIDGET_TYPE_SIGNATURE: typing.ClassVar[int] = ...
    WIDGET_TYPE_TEXTFIELD: typing.ClassVar[int] = ...
    WIDGET_TYPE_UNKNOWN: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAccessibilityLabel(self) -> str | None: ...
    def getFontSize(self) -> float: ...
    def getListItems(self) -> java.util.List[ListItem]: ...
    def getMaxLength(self) -> int: ...
    def getTextValue(self) -> str | None: ...
    def getWidgetIndex(self) -> int: ...
    def getWidgetRect(self) -> android.graphics.Rect: ...
    def getWidgetType(self) -> int: ...
    def hashCode(self) -> int: ...
    def isEditableText(self) -> bool: ...
    def isMultiLineText(self) -> bool: ...
    def isMultiSelect(self) -> bool: ...
    def isReadOnly(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, widgetType: int | java.jint | java.lang.Integer, widgetIndex: int | java.jint | java.lang.Integer, widgetRect: android.graphics.Rect, textValue: str | java.lang.String, accessibilityLabel: str | java.lang.String, /) -> None: ...
        def build(self) -> FormWidgetInfo: ...
        def setEditableText(self, editableText: bool | java.jboolean | java.lang.Boolean, /) -> FormWidgetInfo.Builder: ...
        def setFontSize(self, fontSize: float | java.jfloat | java.lang.Float, /) -> FormWidgetInfo.Builder: ...
        def setListItems(self, listItems: java.util.List[ListItem], /) -> FormWidgetInfo.Builder: ...
        def setMaxLength(self, maxLength: int | java.jint | java.lang.Integer, /) -> FormWidgetInfo.Builder: ...
        def setMultiLineText(self, multiLineText: bool | java.jboolean | java.lang.Boolean, /) -> FormWidgetInfo.Builder: ...
        def setMultiSelect(self, multiSelect: bool | java.jboolean | java.lang.Boolean, /) -> FormWidgetInfo.Builder: ...
        def setReadOnly(self, readOnly: bool | java.jboolean | java.lang.Boolean, /) -> FormWidgetInfo.Builder: ...

class ListItem(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[ListItem]] = ...
    def __init__(self, label: str | java.lang.String, selected: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def describeContents(self) -> int: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getLabel(self) -> str: ...
    def hashCode(self) -> int: ...
    def isSelected(self) -> bool: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class PageMatchBounds(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PageMatchBounds]] = ...
    def __init__(self, bounds: java.util.List[android.graphics.RectF], textStartIndex: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def getBounds(self) -> java.util.List[android.graphics.RectF]: ...
    def getTextStartIndex(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...



import typing

import java
import java.chaquopy
import java.lang
import java.text
import java.time
import java.time.chrono
import java.time.temporal
import java.util

class DateTimeFormatter(java.lang.Object):
    BASIC_ISO_DATE: typing.ClassVar[DateTimeFormatter] = ...
    ISO_DATE: typing.ClassVar[DateTimeFormatter] = ...
    ISO_DATE_TIME: typing.ClassVar[DateTimeFormatter] = ...
    ISO_INSTANT: typing.ClassVar[DateTimeFormatter] = ...
    ISO_LOCAL_DATE: typing.ClassVar[DateTimeFormatter] = ...
    ISO_LOCAL_DATE_TIME: typing.ClassVar[DateTimeFormatter] = ...
    ISO_LOCAL_TIME: typing.ClassVar[DateTimeFormatter] = ...
    ISO_OFFSET_DATE: typing.ClassVar[DateTimeFormatter] = ...
    ISO_OFFSET_DATE_TIME: typing.ClassVar[DateTimeFormatter] = ...
    ISO_OFFSET_TIME: typing.ClassVar[DateTimeFormatter] = ...
    ISO_ORDINAL_DATE: typing.ClassVar[DateTimeFormatter] = ...
    ISO_TIME: typing.ClassVar[DateTimeFormatter] = ...
    ISO_WEEK_DATE: typing.ClassVar[DateTimeFormatter] = ...
    ISO_ZONED_DATE_TIME: typing.ClassVar[DateTimeFormatter] = ...
    RFC_1123_DATE_TIME: typing.ClassVar[DateTimeFormatter] = ...
    def format(self, temporal: java.time.temporal.TemporalAccessor, /) -> str: ...
    def formatTo(self, temporal: java.time.temporal.TemporalAccessor, appendable: java.lang.Appendable, /) -> None: ...
    def getChronology(self) -> java.time.chrono.Chronology: ...
    def getDecimalStyle(self) -> DecimalStyle: ...
    def getLocale(self) -> java.util.Locale: ...
    def getResolverFields(self) -> java.util.Set[java.time.temporal.TemporalField]: ...
    def getResolverStyle(self) -> ResolverStyle: ...
    def getZone(self) -> java.time.ZoneId: ...
    def localizedBy(self, locale: java.util.Locale, /) -> DateTimeFormatter: ...
    @staticmethod
    def ofLocalizedDate(dateStyle: FormatStyle, /) -> DateTimeFormatter: ...
    @typing.overload
    @staticmethod
    def ofLocalizedDateTime(dateTimeStyle: FormatStyle, /) -> DateTimeFormatter: ...
    @typing.overload
    @staticmethod
    def ofLocalizedDateTime(dateStyle: FormatStyle, timeStyle: FormatStyle, /) -> DateTimeFormatter: ...
    @staticmethod
    def ofLocalizedTime(timeStyle: FormatStyle, /) -> DateTimeFormatter: ...
    @typing.overload
    @staticmethod
    def ofPattern(pattern: str | java.lang.String, /) -> DateTimeFormatter: ...
    @typing.overload
    @staticmethod
    def ofPattern(pattern: str | java.lang.String, locale: java.util.Locale, /) -> DateTimeFormatter: ...
    _parse_2__T = typing.TypeVar('_parse_2__T')  # <T>
    @typing.overload
    def parse(self, text: java.lang.CharSequence, /) -> java.time.temporal.TemporalAccessor: ...
    @typing.overload
    def parse(self, text: java.lang.CharSequence, position: java.text.ParsePosition, /) -> java.time.temporal.TemporalAccessor: ...
    @typing.overload
    def parse(self, text: java.lang.CharSequence, query: java.time.temporal.TemporalQuery[_parse_2__T], /) -> _parse_2__T: ...
    def parseBest(self, text: java.lang.CharSequence, /, *queries: java.time.temporal.TemporalQuery[java.lang.Object]) -> java.time.temporal.TemporalAccessor: ...
    def parseUnresolved(self, text: java.lang.CharSequence, position: java.text.ParsePosition, /) -> java.time.temporal.TemporalAccessor: ...
    @staticmethod
    def parsedExcessDays() -> java.time.temporal.TemporalQuery[java.time.Period]: ...
    @staticmethod
    def parsedLeapSecond() -> java.time.temporal.TemporalQuery[java.lang.Boolean]: ...
    @typing.overload
    def toFormat(self) -> java.text.Format: ...
    @typing.overload
    def toFormat(self, parseQuery: java.time.temporal.TemporalQuery[java.lang.Object], /) -> java.text.Format: ...
    def toString(self) -> str: ...
    def withChronology(self, chrono: java.time.chrono.Chronology, /) -> DateTimeFormatter: ...
    def withDecimalStyle(self, decimalStyle: DecimalStyle, /) -> DateTimeFormatter: ...
    def withLocale(self, locale: java.util.Locale, /) -> DateTimeFormatter: ...
    @typing.overload
    def withResolverFields(self, resolverFields: java.util.Set[java.time.temporal.TemporalField], /) -> DateTimeFormatter: ...
    @typing.overload
    def withResolverFields(self, *resolverFields: java.time.temporal.TemporalField) -> DateTimeFormatter: ...
    def withResolverStyle(self, resolverStyle: ResolverStyle, /) -> DateTimeFormatter: ...
    def withZone(self, zone: java.time.ZoneId, /) -> DateTimeFormatter: ...

class DateTimeFormatterBuilder(java.lang.Object):
    def __init__(self) -> None: ...
    def append(self, formatter: DateTimeFormatter, /) -> DateTimeFormatterBuilder: ...
    def appendChronologyId(self) -> DateTimeFormatterBuilder: ...
    def appendChronologyText(self, textStyle: TextStyle, /) -> DateTimeFormatterBuilder: ...
    def appendFraction(self, field: java.time.temporal.TemporalField, minWidth: int | java.jint | java.lang.Integer, maxWidth: int | java.jint | java.lang.Integer, decimalPoint: bool | java.jboolean | java.lang.Boolean, /) -> DateTimeFormatterBuilder: ...
    @typing.overload
    def appendGenericZoneText(self, textStyle: TextStyle, /) -> DateTimeFormatterBuilder: ...
    @typing.overload
    def appendGenericZoneText(self, textStyle: TextStyle, preferredZones: java.util.Set[java.time.ZoneId], /) -> DateTimeFormatterBuilder: ...
    @typing.overload
    def appendInstant(self) -> DateTimeFormatterBuilder: ...
    @typing.overload
    def appendInstant(self, fractionalDigits: int | java.jint | java.lang.Integer, /) -> DateTimeFormatterBuilder: ...
    @typing.overload
    def appendLiteral(self, literal: str | java.jchar | java.lang.Character, /) -> DateTimeFormatterBuilder: ...
    @typing.overload
    def appendLiteral(self, literal: str | java.lang.String, /) -> DateTimeFormatterBuilder: ...
    def appendLocalized(self, dateStyle: FormatStyle, timeStyle: FormatStyle, /) -> DateTimeFormatterBuilder: ...
    def appendLocalizedOffset(self, style: TextStyle, /) -> DateTimeFormatterBuilder: ...
    def appendOffset(self, pattern: str | java.lang.String, noOffsetText: str | java.lang.String, /) -> DateTimeFormatterBuilder: ...
    def appendOffsetId(self) -> DateTimeFormatterBuilder: ...
    def appendOptional(self, formatter: DateTimeFormatter, /) -> DateTimeFormatterBuilder: ...
    def appendPattern(self, pattern: str | java.lang.String, /) -> DateTimeFormatterBuilder: ...
    @typing.overload
    def appendText(self, field: java.time.temporal.TemporalField, /) -> DateTimeFormatterBuilder: ...
    @typing.overload
    def appendText(self, field: java.time.temporal.TemporalField, textStyle: TextStyle, /) -> DateTimeFormatterBuilder: ...
    @typing.overload
    def appendText(self, field: java.time.temporal.TemporalField, textLookup: java.util.Map[java.lang.Long, java.lang.String], /) -> DateTimeFormatterBuilder: ...
    @typing.overload
    def appendValue(self, field: java.time.temporal.TemporalField, /) -> DateTimeFormatterBuilder: ...
    @typing.overload
    def appendValue(self, field: java.time.temporal.TemporalField, width: int | java.jint | java.lang.Integer, /) -> DateTimeFormatterBuilder: ...
    @typing.overload
    def appendValue(self, field: java.time.temporal.TemporalField, minWidth: int | java.jint | java.lang.Integer, maxWidth: int | java.jint | java.lang.Integer, signStyle: SignStyle, /) -> DateTimeFormatterBuilder: ...
    @typing.overload
    def appendValueReduced(self, field: java.time.temporal.TemporalField, width: int | java.jint | java.lang.Integer, maxWidth: int | java.jint | java.lang.Integer, baseValue: int | java.jint | java.lang.Integer, /) -> DateTimeFormatterBuilder: ...
    @typing.overload
    def appendValueReduced(self, field: java.time.temporal.TemporalField, width: int | java.jint | java.lang.Integer, maxWidth: int | java.jint | java.lang.Integer, baseDate: java.time.chrono.ChronoLocalDate, /) -> DateTimeFormatterBuilder: ...
    def appendZoneId(self) -> DateTimeFormatterBuilder: ...
    def appendZoneOrOffsetId(self) -> DateTimeFormatterBuilder: ...
    def appendZoneRegionId(self) -> DateTimeFormatterBuilder: ...
    @typing.overload
    def appendZoneText(self, textStyle: TextStyle, /) -> DateTimeFormatterBuilder: ...
    @typing.overload
    def appendZoneText(self, textStyle: TextStyle, preferredZones: java.util.Set[java.time.ZoneId], /) -> DateTimeFormatterBuilder: ...
    @staticmethod
    def getLocalizedDateTimePattern(dateStyle: FormatStyle, timeStyle: FormatStyle, chrono: java.time.chrono.Chronology, locale: java.util.Locale, /) -> str: ...
    def optionalEnd(self) -> DateTimeFormatterBuilder: ...
    def optionalStart(self) -> DateTimeFormatterBuilder: ...
    @typing.overload
    def padNext(self, padWidth: int | java.jint | java.lang.Integer, /) -> DateTimeFormatterBuilder: ...
    @typing.overload
    def padNext(self, padWidth: int | java.jint | java.lang.Integer, padChar: str | java.jchar | java.lang.Character, /) -> DateTimeFormatterBuilder: ...
    def parseCaseInsensitive(self) -> DateTimeFormatterBuilder: ...
    def parseCaseSensitive(self) -> DateTimeFormatterBuilder: ...
    def parseDefaulting(self, field: java.time.temporal.TemporalField, value: int | java.jlong | java.lang.Long, /) -> DateTimeFormatterBuilder: ...
    def parseLenient(self) -> DateTimeFormatterBuilder: ...
    def parseStrict(self) -> DateTimeFormatterBuilder: ...
    @typing.overload
    def toFormatter(self) -> DateTimeFormatter: ...
    @typing.overload
    def toFormatter(self, locale: java.util.Locale, /) -> DateTimeFormatter: ...

class DateTimeParseException(java.time.DateTimeException):
    @typing.overload
    def __init__(self, message: str | java.lang.String, parsedData: java.lang.CharSequence, errorIndex: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, message: str | java.lang.String, parsedData: java.lang.CharSequence, errorIndex: int | java.jint | java.lang.Integer, cause: java.lang.Throwable, /) -> None: ...
    def getErrorIndex(self) -> int: ...
    def getParsedString(self) -> str: ...

class DecimalStyle(java.lang.Object):
    STANDARD: typing.ClassVar[DecimalStyle] = ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    @staticmethod
    def getAvailableLocales() -> java.util.Set[java.util.Locale]: ...
    def getDecimalSeparator(self) -> str: ...
    def getNegativeSign(self) -> str: ...
    def getPositiveSign(self) -> str: ...
    def getZeroDigit(self) -> str: ...
    def hashCode(self) -> int: ...
    @staticmethod
    def of(locale: java.util.Locale, /) -> DecimalStyle: ...
    @staticmethod
    def ofDefaultLocale() -> DecimalStyle: ...
    def toString(self) -> str: ...
    def withDecimalSeparator(self, decimalSeparator: str | java.jchar | java.lang.Character, /) -> DecimalStyle: ...
    def withNegativeSign(self, negativeSign: str | java.jchar | java.lang.Character, /) -> DecimalStyle: ...
    def withPositiveSign(self, positiveSign: str | java.jchar | java.lang.Character, /) -> DecimalStyle: ...
    def withZeroDigit(self, zeroDigit: str | java.jchar | java.lang.Character, /) -> DecimalStyle: ...

class FormatStyle(java.lang.Enum[FormatStyle]):
    FULL: typing.ClassVar[FormatStyle] = ...
    LONG: typing.ClassVar[FormatStyle] = ...
    MEDIUM: typing.ClassVar[FormatStyle] = ...
    SHORT: typing.ClassVar[FormatStyle] = ...
    @staticmethod
    def valueOf(name: str | java.lang.String, /) -> FormatStyle: ...
    @staticmethod
    def values() -> java.chaquopy.JavaArray[FormatStyle]: ...

class ResolverStyle(java.lang.Enum[ResolverStyle]):
    LENIENT: typing.ClassVar[ResolverStyle] = ...
    SMART: typing.ClassVar[ResolverStyle] = ...
    STRICT: typing.ClassVar[ResolverStyle] = ...
    @staticmethod
    def valueOf(name: str | java.lang.String, /) -> ResolverStyle: ...
    @staticmethod
    def values() -> java.chaquopy.JavaArray[ResolverStyle]: ...

class SignStyle(java.lang.Enum[SignStyle]):
    ALWAYS: typing.ClassVar[SignStyle] = ...
    EXCEEDS_PAD: typing.ClassVar[SignStyle] = ...
    NEVER: typing.ClassVar[SignStyle] = ...
    NORMAL: typing.ClassVar[SignStyle] = ...
    NOT_NEGATIVE: typing.ClassVar[SignStyle] = ...
    @staticmethod
    def valueOf(name: str | java.lang.String, /) -> SignStyle: ...
    @staticmethod
    def values() -> java.chaquopy.JavaArray[SignStyle]: ...

class TextStyle(java.lang.Enum[TextStyle]):
    FULL: typing.ClassVar[TextStyle] = ...
    FULL_STANDALONE: typing.ClassVar[TextStyle] = ...
    NARROW: typing.ClassVar[TextStyle] = ...
    NARROW_STANDALONE: typing.ClassVar[TextStyle] = ...
    SHORT: typing.ClassVar[TextStyle] = ...
    SHORT_STANDALONE: typing.ClassVar[TextStyle] = ...
    def asNormal(self) -> TextStyle: ...
    def asStandalone(self) -> TextStyle: ...
    def isStandalone(self) -> bool: ...
    @staticmethod
    def valueOf(name: str | java.lang.String, /) -> TextStyle: ...
    @staticmethod
    def values() -> java.chaquopy.JavaArray[TextStyle]: ...



import typing

import java
import java.chaquopy
import java.lang

class AppJankStats(java.lang.Object):
    WIDGET_CATEGORY_ANIMATION: typing.ClassVar[str] = ...
    WIDGET_CATEGORY_KEYBOARD: typing.ClassVar[str] = ...
    WIDGET_CATEGORY_MEDIA: typing.ClassVar[str] = ...
    WIDGET_CATEGORY_NAVIGATION: typing.ClassVar[str] = ...
    WIDGET_CATEGORY_OTHER: typing.ClassVar[str] = ...
    WIDGET_CATEGORY_SCROLL: typing.ClassVar[str] = ...
    WIDGET_CATEGORY_UNSPECIFIED: typing.ClassVar[str] = ...
    WIDGET_STATE_ANIMATING: typing.ClassVar[str] = ...
    WIDGET_STATE_DRAGGING: typing.ClassVar[str] = ...
    WIDGET_STATE_FLINGING: typing.ClassVar[str] = ...
    WIDGET_STATE_NONE: typing.ClassVar[str] = ...
    WIDGET_STATE_PLAYBACK: typing.ClassVar[str] = ...
    WIDGET_STATE_PREDICTIVE_BACK: typing.ClassVar[str] = ...
    WIDGET_STATE_SCROLLING: typing.ClassVar[str] = ...
    WIDGET_STATE_SWIPING: typing.ClassVar[str] = ...
    WIDGET_STATE_TAPPING: typing.ClassVar[str] = ...
    WIDGET_STATE_UNSPECIFIED: typing.ClassVar[str] = ...
    WIDGET_STATE_ZOOMING: typing.ClassVar[str] = ...
    def __init__(self, appUid: int | java.jint | java.lang.Integer, widgetId: str | java.lang.String, navigationComponent: str | java.lang.String, widgetCategory: str | java.lang.String, widgetState: str | java.lang.String, totalFrames: int | java.jlong | java.lang.Long, jankyFrames: int | java.jlong | java.lang.Long, relativeFrameTimeHistogram: RelativeFrameTimeHistogram, /) -> None: ...
    def getJankyFrameCount(self) -> int: ...
    def getNavigationComponent(self) -> str: ...
    def getRelativeFrameTimeHistogram(self) -> RelativeFrameTimeHistogram: ...
    def getTotalFrameCount(self) -> int: ...
    def getUid(self) -> int: ...
    def getWidgetCategory(self) -> str: ...
    def getWidgetId(self) -> str: ...
    def getWidgetState(self) -> str: ...

class RelativeFrameTimeHistogram(java.lang.Object):
    def __init__(self) -> None: ...
    def addRelativeFrameTimeMillis(self, frameTimeMillis: int | java.jint | java.lang.Integer, /) -> None: ...
    def getBucketCounters(self) -> java.chaquopy.JavaArrayJInt: ...
    def getBucketEndpointsMillis(self) -> java.chaquopy.JavaArrayJInt: ...



import typing

import java
import java.io
import java.lang
import javax.xml.validation
import org.w3c.dom
import org.xml.sax
import org.xml.sax.helpers

class DocumentBuilder(java.lang.Object):
    def __init__(self) -> None: ...
    def getDOMImplementation(self) -> org.w3c.dom.DOMImplementation: ...
    def getSchema(self) -> javax.xml.validation.Schema: ...
    def isNamespaceAware(self) -> bool: ...
    def isValidating(self) -> bool: ...
    def isXIncludeAware(self) -> bool: ...
    def newDocument(self) -> org.w3c.dom.Document: ...
    @typing.overload
    def parse(self, f: java.io.File, /) -> org.w3c.dom.Document: ...
    @typing.overload
    def parse(self, is_: java.io.InputStream, /) -> org.w3c.dom.Document: ...
    @typing.overload
    def parse(self, uri: str | java.lang.String, /) -> org.w3c.dom.Document: ...
    @typing.overload
    def parse(self, arg1: org.xml.sax.InputSource, /) -> org.w3c.dom.Document: ...
    @typing.overload
    def parse(self, is_: java.io.InputStream, systemId: str | java.lang.String, /) -> org.w3c.dom.Document: ...
    def reset(self) -> None: ...
    def setEntityResolver(self, arg1: org.xml.sax.EntityResolver, /) -> None: ...
    def setErrorHandler(self, arg1: org.xml.sax.ErrorHandler, /) -> None: ...

class DocumentBuilderFactory(java.lang.Object):
    def __init__(self) -> None: ...
    def getAttribute(self, arg1: str | java.lang.String, /) -> java.lang.Object: ...
    def getFeature(self, arg1: str | java.lang.String, /) -> bool: ...
    def getSchema(self) -> javax.xml.validation.Schema: ...
    def isCoalescing(self) -> bool: ...
    def isExpandEntityReferences(self) -> bool: ...
    def isIgnoringComments(self) -> bool: ...
    def isIgnoringElementContentWhitespace(self) -> bool: ...
    def isNamespaceAware(self) -> bool: ...
    def isValidating(self) -> bool: ...
    def isXIncludeAware(self) -> bool: ...
    def newDocumentBuilder(self) -> DocumentBuilder: ...
    @typing.overload
    @staticmethod
    def newInstance() -> DocumentBuilderFactory: ...
    @typing.overload
    @staticmethod
    def newInstance(factoryClassName: str | java.lang.String, classLoader: java.lang.ClassLoader, /) -> DocumentBuilderFactory: ...
    def setAttribute(self, arg1: str | java.lang.String, arg2: java.lang.Object | int | bool | float | str, /) -> None: ...
    def setCoalescing(self, coalescing: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setExpandEntityReferences(self, expandEntityRef: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setFeature(self, arg1: str | java.lang.String, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setIgnoringComments(self, ignoreComments: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setIgnoringElementContentWhitespace(self, whitespace: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setNamespaceAware(self, awareness: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSchema(self, schema: javax.xml.validation.Schema, /) -> None: ...
    def setValidating(self, validating: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setXIncludeAware(self, state: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

class FactoryConfigurationError(java.lang.Error):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, e: java.lang.Exception, /) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, /) -> None: ...
    @typing.overload
    def __init__(self, e: java.lang.Exception, msg: str | java.lang.String, /) -> None: ...
    def getException(self) -> java.lang.Exception: ...
    def getMessage(self) -> str: ...

class ParserConfigurationException(java.lang.Exception):
    @typing.overload
    def __init__(self) -> None: ...
    @typing.overload
    def __init__(self, msg: str | java.lang.String, /) -> None: ...

class SAXParser(java.lang.Object):
    def __init__(self) -> None: ...
    def getParser(self) -> org.xml.sax.Parser: ...
    def getProperty(self, arg1: str | java.lang.String, /) -> java.lang.Object: ...
    def getSchema(self) -> javax.xml.validation.Schema: ...
    def getXMLReader(self) -> org.xml.sax.XMLReader: ...
    def isNamespaceAware(self) -> bool: ...
    def isValidating(self) -> bool: ...
    def isXIncludeAware(self) -> bool: ...
    @typing.overload
    def parse(self, f: java.io.File, hb: org.xml.sax.HandlerBase, /) -> None: ...
    @typing.overload
    def parse(self, f: java.io.File, dh: org.xml.sax.helpers.DefaultHandler, /) -> None: ...
    @typing.overload
    def parse(self, is_: java.io.InputStream, hb: org.xml.sax.HandlerBase, /) -> None: ...
    @typing.overload
    def parse(self, is_: java.io.InputStream, dh: org.xml.sax.helpers.DefaultHandler, /) -> None: ...
    @typing.overload
    def parse(self, uri: str | java.lang.String, hb: org.xml.sax.HandlerBase, /) -> None: ...
    @typing.overload
    def parse(self, uri: str | java.lang.String, dh: org.xml.sax.helpers.DefaultHandler, /) -> None: ...
    @typing.overload
    def parse(self, is_: org.xml.sax.InputSource, hb: org.xml.sax.HandlerBase, /) -> None: ...
    @typing.overload
    def parse(self, is_: org.xml.sax.InputSource, dh: org.xml.sax.helpers.DefaultHandler, /) -> None: ...
    @typing.overload
    def parse(self, is_: java.io.InputStream, hb: org.xml.sax.HandlerBase, systemId: str | java.lang.String, /) -> None: ...
    @typing.overload
    def parse(self, is_: java.io.InputStream, dh: org.xml.sax.helpers.DefaultHandler, systemId: str | java.lang.String, /) -> None: ...
    def reset(self) -> None: ...
    def setProperty(self, arg1: str | java.lang.String, arg2: java.lang.Object | int | bool | float | str, /) -> None: ...

class SAXParserFactory(java.lang.Object):
    def __init__(self) -> None: ...
    def getFeature(self, arg1: str | java.lang.String, /) -> bool: ...
    def getSchema(self) -> javax.xml.validation.Schema: ...
    def isNamespaceAware(self) -> bool: ...
    def isValidating(self) -> bool: ...
    def isXIncludeAware(self) -> bool: ...
    @typing.overload
    @staticmethod
    def newInstance() -> SAXParserFactory: ...
    @typing.overload
    @staticmethod
    def newInstance(factoryClassName: str | java.lang.String, classLoader: java.lang.ClassLoader, /) -> SAXParserFactory: ...
    def newSAXParser(self) -> SAXParser: ...
    def setFeature(self, arg1: str | java.lang.String, arg2: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setNamespaceAware(self, awareness: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setSchema(self, schema: javax.xml.validation.Schema, /) -> None: ...
    def setValidating(self, validating: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setXIncludeAware(self, state: bool | java.jboolean | java.lang.Boolean, /) -> None: ...



import typing

import android.app
import android.content
import android.content.pm
import android.graphics
import android.graphics.drawable
import android.media
import android.media.tv.interactive
import android.net
import android.os
import android.provider
import android.util
import android.view
import java
import java.chaquopy
import java.lang
import java.util

class AdBuffer(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AdBuffer]] = ...
    def __init__(self, id: int | java.jint | java.lang.Integer, mimeType: str | java.lang.String, buffer: android.os.SharedMemory, offset: int | java.jint | java.lang.Integer, length: int | java.jint | java.lang.Integer, presentationTimeUs: int | java.jlong | java.lang.Long, flags: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def getFlags(self) -> int: ...
    def getId(self) -> int: ...
    def getLength(self) -> int: ...
    def getMimeType(self) -> str: ...
    def getOffset(self) -> int: ...
    def getPresentationTimeUs(self) -> int: ...
    def getSharedMemory(self) -> android.os.SharedMemory: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class AdRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AdRequest]] = ...
    REQUEST_TYPE_START: typing.ClassVar[int] = ...
    REQUEST_TYPE_STOP: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, id: int | java.jint | java.lang.Integer, requestType: int | java.jint | java.lang.Integer, uri: android.net.Uri, startTime: int | java.jlong | java.lang.Long, stopTime: int | java.jlong | java.lang.Long, echoInterval: int | java.jlong | java.lang.Long, metadata: android.os.Bundle, /) -> None: ...
    @typing.overload
    def __init__(self, id: int | java.jint | java.lang.Integer, requestType: int | java.jint | java.lang.Integer, fileDescriptor: android.os.ParcelFileDescriptor, startTime: int | java.jlong | java.lang.Long, stopTime: int | java.jlong | java.lang.Long, echoInterval: int | java.jlong | java.lang.Long, mediaFileType: str | java.lang.String, metadata: android.os.Bundle, /) -> None: ...
    def describeContents(self) -> int: ...
    def getEchoIntervalMillis(self) -> int: ...
    def getFileDescriptor(self) -> android.os.ParcelFileDescriptor | None: ...
    def getId(self) -> int: ...
    def getMediaFileType(self) -> str | None: ...
    def getMetadata(self) -> android.os.Bundle: ...
    def getRequestType(self) -> int: ...
    def getStartTimeMillis(self) -> int: ...
    def getStopTimeMillis(self) -> int: ...
    def getUri(self) -> android.net.Uri | None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class AdResponse(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AdResponse]] = ...
    RESPONSE_TYPE_BUFFERING: typing.ClassVar[int] = ...
    RESPONSE_TYPE_ERROR: typing.ClassVar[int] = ...
    RESPONSE_TYPE_FINISHED: typing.ClassVar[int] = ...
    RESPONSE_TYPE_PLAYING: typing.ClassVar[int] = ...
    RESPONSE_TYPE_STOPPED: typing.ClassVar[int] = ...
    def __init__(self, id: int | java.jint | java.lang.Integer, responseType: int | java.jint | java.lang.Integer, elapsedTime: int | java.jlong | java.lang.Long, /) -> None: ...
    def describeContents(self) -> int: ...
    def getElapsedTimeMillis(self) -> int: ...
    def getId(self) -> int: ...
    def getResponseType(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class AitInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[AitInfo]] = ...
    def __init__(self, type: int | java.jint | java.lang.Integer, version: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def getType(self) -> int: ...
    def getVersion(self) -> int: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class BroadcastInfoRequest(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BroadcastInfoRequest]] = ...
    REQUEST_OPTION_AUTO_UPDATE: typing.ClassVar[int] = ...
    REQUEST_OPTION_ONESHOT: typing.ClassVar[int] = ...
    REQUEST_OPTION_ONEWAY: typing.ClassVar[int] = ...
    REQUEST_OPTION_REPEAT: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getOption(self) -> int: ...
    def getRequestId(self) -> int: ...
    def getType(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class BroadcastInfoResponse(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[BroadcastInfoResponse]] = ...
    RESPONSE_RESULT_CANCEL: typing.ClassVar[int] = ...
    RESPONSE_RESULT_ERROR: typing.ClassVar[int] = ...
    RESPONSE_RESULT_OK: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def getRequestId(self) -> int: ...
    def getResponseResult(self) -> int: ...
    def getSequence(self) -> int: ...
    def getType(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CommandRequest(BroadcastInfoRequest, android.os.Parcelable):
    ARGUMENT_TYPE_JSON: typing.ClassVar[str] = ...
    ARGUMENT_TYPE_XML: typing.ClassVar[str] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CommandRequest]] = ...
    def __init__(self, requestId: int | java.jint | java.lang.Integer, option: int | java.jint | java.lang.Integer, namespace: str | java.lang.String, name: str | java.lang.String, arguments: str | java.lang.String, argumentType: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def getArgumentType(self) -> str: ...
    def getArguments(self) -> str: ...
    def getName(self) -> str: ...
    def getNamespace(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class CommandResponse(BroadcastInfoResponse, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[CommandResponse]] = ...
    RESPONSE_TYPE_JSON: typing.ClassVar[str] = ...
    RESPONSE_TYPE_XML: typing.ClassVar[str] = ...
    def __init__(self, requestId: int | java.jint | java.lang.Integer, sequence: int | java.jint | java.lang.Integer, responseResult: int | java.jint | java.lang.Integer, response: str | java.lang.String, responseType: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def getResponse(self) -> str | None: ...
    def getResponseType(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class DsmccRequest(BroadcastInfoRequest, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[DsmccRequest]] = ...
    def __init__(self, requestId: int | java.jint | java.lang.Integer, option: int | java.jint | java.lang.Integer, uri: android.net.Uri, /) -> None: ...
    def describeContents(self) -> int: ...
    def getUri(self) -> android.net.Uri: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class DsmccResponse(BroadcastInfoResponse, android.os.Parcelable):
    BIOP_MESSAGE_TYPE_DIRECTORY: typing.ClassVar[str] = ...
    BIOP_MESSAGE_TYPE_FILE: typing.ClassVar[str] = ...
    BIOP_MESSAGE_TYPE_SERVICE_GATEWAY: typing.ClassVar[str] = ...
    BIOP_MESSAGE_TYPE_STREAM: typing.ClassVar[str] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[DsmccResponse]] = ...
    @typing.overload
    def __init__(self, requestId: int | java.jint | java.lang.Integer, sequence: int | java.jint | java.lang.Integer, responseResult: int | java.jint | java.lang.Integer, file: android.os.ParcelFileDescriptor, /) -> None: ...
    @typing.overload
    def __init__(self, requestId: int | java.jint | java.lang.Integer, sequence: int | java.jint | java.lang.Integer, responseResult: int | java.jint | java.lang.Integer, isServiceGateway: bool | java.jboolean | java.lang.Boolean, childList: java.util.List[java.lang.String], /) -> None: ...
    @typing.overload
    def __init__(self, requestId: int | java.jint | java.lang.Integer, sequence: int | java.jint | java.lang.Integer, responseResult: int | java.jint | java.lang.Integer, eventIds: java.chaquopy.JavaArrayJInt, eventNames: java.chaquopy.JavaArray[java.lang.String], /) -> None: ...
    def describeContents(self) -> int: ...
    def getBiopMessageType(self) -> str: ...
    def getChildList(self) -> java.util.List[java.lang.String]: ...
    def getFile(self) -> android.os.ParcelFileDescriptor: ...
    def getStreamEventIds(self) -> java.chaquopy.JavaArrayJInt: ...
    def getStreamEventNames(self) -> java.chaquopy.JavaArray[java.lang.String]: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class PesRequest(BroadcastInfoRequest, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PesRequest]] = ...
    def __init__(self, requestId: int | java.jint | java.lang.Integer, option: int | java.jint | java.lang.Integer, tsPid: int | java.jint | java.lang.Integer, streamId: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def getStreamId(self) -> int: ...
    def getTsPid(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class PesResponse(BroadcastInfoResponse, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[PesResponse]] = ...
    def __init__(self, requestId: int | java.jint | java.lang.Integer, sequence: int | java.jint | java.lang.Integer, responseResult: int | java.jint | java.lang.Integer, sharedFilterToken: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def getSharedFilterToken(self) -> str | None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class SectionRequest(BroadcastInfoRequest, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SectionRequest]] = ...
    def __init__(self, requestId: int | java.jint | java.lang.Integer, option: int | java.jint | java.lang.Integer, tsPid: int | java.jint | java.lang.Integer, tableId: int | java.jint | java.lang.Integer, version: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def getTableId(self) -> int: ...
    def getTsPid(self) -> int: ...
    def getVersion(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class SectionResponse(BroadcastInfoResponse, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SectionResponse]] = ...
    def __init__(self, requestId: int | java.jint | java.lang.Integer, sequence: int | java.jint | java.lang.Integer, responseResult: int | java.jint | java.lang.Integer, sessionId: int | java.jint | java.lang.Integer, version: int | java.jint | java.lang.Integer, sessionData: android.os.Bundle, /) -> None: ...
    def describeContents(self) -> int: ...
    def getSessionData(self) -> android.os.Bundle: ...
    def getSessionId(self) -> int: ...
    def getVersion(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class SignalingDataInfo(android.os.Parcelable):
    CONTENT_ENCODING_BASE64: typing.ClassVar[str] = ...
    CONTENT_ENCODING_UTF_8: typing.ClassVar[str] = ...
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SignalingDataInfo]] = ...
    LLS_NO_GROUP_ID: typing.ClassVar[int] = ...
    @typing.overload
    def __init__(self, table: str | java.lang.String, signalingDataType: str | java.lang.String, version: int | java.jint | java.lang.Integer, group: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, table: str | java.lang.String, signalingDataType: str | java.lang.String, version: int | java.jint | java.lang.Integer, group: int | java.jint | java.lang.Integer, encoding: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def getEncoding(self) -> str: ...
    def getGroup(self) -> int: ...
    def getSignalingDataType(self) -> str: ...
    def getTable(self) -> str: ...
    def getVersion(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class SignalingDataRequest(BroadcastInfoRequest, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SignalingDataRequest]] = ...
    SIGNALING_DATA_NO_GROUP_ID: typing.ClassVar[int] = ...
    SIGNALING_METADATA_AEAT: typing.ClassVar[str] = ...
    SIGNALING_METADATA_AEI: typing.ClassVar[str] = ...
    SIGNALING_METADATA_APD: typing.ClassVar[str] = ...
    SIGNALING_METADATA_ASD: typing.ClassVar[str] = ...
    SIGNALING_METADATA_ASPD: typing.ClassVar[str] = ...
    SIGNALING_METADATA_CAD: typing.ClassVar[str] = ...
    SIGNALING_METADATA_CDT: typing.ClassVar[str] = ...
    SIGNALING_METADATA_CRIT: typing.ClassVar[str] = ...
    SIGNALING_METADATA_DCIT: typing.ClassVar[str] = ...
    SIGNALING_METADATA_DWD: typing.ClassVar[str] = ...
    SIGNALING_METADATA_EMSG: typing.ClassVar[str] = ...
    SIGNALING_METADATA_EVTI: typing.ClassVar[str] = ...
    SIGNALING_METADATA_HELD: typing.ClassVar[str] = ...
    SIGNALING_METADATA_IED: typing.ClassVar[str] = ...
    SIGNALING_METADATA_MPD: typing.ClassVar[str] = ...
    SIGNALING_METADATA_MPIT: typing.ClassVar[str] = ...
    SIGNALING_METADATA_MPT: typing.ClassVar[str] = ...
    SIGNALING_METADATA_OSN: typing.ClassVar[str] = ...
    SIGNALING_METADATA_PAT: typing.ClassVar[str] = ...
    SIGNALING_METADATA_RDT: typing.ClassVar[str] = ...
    SIGNALING_METADATA_RRT: typing.ClassVar[str] = ...
    SIGNALING_METADATA_RSAT: typing.ClassVar[str] = ...
    SIGNALING_METADATA_SLT: typing.ClassVar[str] = ...
    SIGNALING_METADATA_SMT: typing.ClassVar[str] = ...
    SIGNALING_METADATA_SSD: typing.ClassVar[str] = ...
    SIGNALING_METADATA_STSID: typing.ClassVar[str] = ...
    SIGNALING_METADATA_STT: typing.ClassVar[str] = ...
    SIGNALING_METADATA_USBD: typing.ClassVar[str] = ...
    SIGNALING_METADATA_USD: typing.ClassVar[str] = ...
    SIGNALING_METADATA_VSPD: typing.ClassVar[str] = ...
    def __init__(self, requestId: int | java.jint | java.lang.Integer, option: int | java.jint | java.lang.Integer, group: int | java.jint | java.lang.Integer, signalingDataTypes: java.util.List[java.lang.String], /) -> None: ...
    def describeContents(self) -> int: ...
    def getGroup(self) -> int: ...
    def getSignalingDataTypes(self) -> java.util.List[java.lang.String]: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class SignalingDataResponse(BroadcastInfoResponse, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[SignalingDataResponse]] = ...
    def __init__(self, requestId: int | java.jint | java.lang.Integer, sequence: int | java.jint | java.lang.Integer, responseResult: int | java.jint | java.lang.Integer, signalingDataTypes: java.util.List[java.lang.String], signalingDataInfoList: java.util.List[SignalingDataInfo], /) -> None: ...
    def describeContents(self) -> int: ...
    def getSignalingDataInfoList(self) -> java.util.List[SignalingDataInfo]: ...
    def getSignalingDataTypes(self) -> java.util.List[java.lang.String]: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class StreamEventRequest(BroadcastInfoRequest, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[StreamEventRequest]] = ...
    def __init__(self, requestId: int | java.jint | java.lang.Integer, option: int | java.jint | java.lang.Integer, targetUri: android.net.Uri, eventName: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def getEventName(self) -> str: ...
    def getTargetUri(self) -> android.net.Uri: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class StreamEventResponse(BroadcastInfoResponse, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[StreamEventResponse]] = ...
    def __init__(self, requestId: int | java.jint | java.lang.Integer, sequence: int | java.jint | java.lang.Integer, responseResult: int | java.jint | java.lang.Integer, eventId: int | java.jint | java.lang.Integer, nptMillis: int | java.jlong | java.lang.Long, data: java.chaquopy.JavaArrayJByte, /) -> None: ...
    def describeContents(self) -> int: ...
    def getData(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def getEventId(self) -> int: ...
    def getNptMillis(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class TableRequest(BroadcastInfoRequest, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TableRequest]] = ...
    TABLE_NAME_BAT: typing.ClassVar[int] = ...
    TABLE_NAME_CAT: typing.ClassVar[int] = ...
    TABLE_NAME_EIT: typing.ClassVar[int] = ...
    TABLE_NAME_NIT: typing.ClassVar[int] = ...
    TABLE_NAME_PAT: typing.ClassVar[int] = ...
    TABLE_NAME_PMT: typing.ClassVar[int] = ...
    TABLE_NAME_SDT: typing.ClassVar[int] = ...
    TABLE_NAME_SIT: typing.ClassVar[int] = ...
    TABLE_NAME_TDT: typing.ClassVar[int] = ...
    TABLE_NAME_TOT: typing.ClassVar[int] = ...
    def __init__(self, requestId: int | java.jint | java.lang.Integer, option: int | java.jint | java.lang.Integer, tableId: int | java.jint | java.lang.Integer, tableName: int | java.jint | java.lang.Integer, version: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def getTableId(self) -> int: ...
    def getTableName(self) -> int: ...
    def getVersion(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class TableResponse(BroadcastInfoResponse, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TableResponse]] = ...
    def __init__(self, requestId: int | java.jint | java.lang.Integer, sequence: int | java.jint | java.lang.Integer, responseResult: int | java.jint | java.lang.Integer, tableUri: android.net.Uri, version: int | java.jint | java.lang.Integer, size: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def getSize(self) -> int: ...
    def getTableByteArray(self) -> java.chaquopy.JavaArrayJByte | None: ...
    def getTableSharedMemory(self) -> android.os.SharedMemory | None: ...
    def getTableUri(self) -> android.net.Uri | None: ...
    def getVersion(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, requestId: int | java.jint | java.lang.Integer, sequence: int | java.jint | java.lang.Integer, responseResult: int | java.jint | java.lang.Integer, version: int | java.jint | java.lang.Integer, size: int | java.jint | java.lang.Integer, /) -> None: ...
        def build(self) -> TableResponse: ...
        def setTableByteArray(self, bytes: java.chaquopy.JavaArrayJByte, /) -> TableResponse.Builder: ...
        def setTableSharedMemory(self, sharedMemory: android.os.SharedMemory, /) -> TableResponse.Builder: ...
        def setTableUri(self, uri: android.net.Uri, /) -> TableResponse.Builder: ...

class TimelineRequest(BroadcastInfoRequest, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TimelineRequest]] = ...
    @typing.overload
    def __init__(self, requestId: int | java.jint | java.lang.Integer, option: int | java.jint | java.lang.Integer, intervalMillis: int | java.jint | java.lang.Integer, /) -> None: ...
    @typing.overload
    def __init__(self, requestId: int | java.jint | java.lang.Integer, option: int | java.jint | java.lang.Integer, intervalMillis: int | java.jint | java.lang.Integer, selector: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def getIntervalMillis(self) -> int: ...
    def getSelector(self) -> str | None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class TimelineResponse(BroadcastInfoResponse, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TimelineResponse]] = ...
    def __init__(self, requestId: int | java.jint | java.lang.Integer, sequence: int | java.jint | java.lang.Integer, responseResult: int | java.jint | java.lang.Integer, selector: str | java.lang.String, unitsPerTick: int | java.jint | java.lang.Integer, unitsPerSecond: int | java.jint | java.lang.Integer, wallClock: int | java.jlong | java.lang.Long, ticks: int | java.jlong | java.lang.Long, /) -> None: ...
    def describeContents(self) -> int: ...
    def getSelector(self) -> android.net.Uri | None: ...
    def getTicks(self) -> int: ...
    def getUnitsPerSecond(self) -> int: ...
    def getUnitsPerTick(self) -> int: ...
    def getWallClock(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class TsRequest(BroadcastInfoRequest, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TsRequest]] = ...
    def __init__(self, requestId: int | java.jint | java.lang.Integer, option: int | java.jint | java.lang.Integer, tsPid: int | java.jint | java.lang.Integer, /) -> None: ...
    def describeContents(self) -> int: ...
    def getTsPid(self) -> int: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class TsResponse(BroadcastInfoResponse, android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TsResponse]] = ...
    def __init__(self, requestId: int | java.jint | java.lang.Integer, sequence: int | java.jint | java.lang.Integer, responseResult: int | java.jint | java.lang.Integer, sharedFilterToken: str | java.lang.String, /) -> None: ...
    def describeContents(self) -> int: ...
    def getSharedFilterToken(self) -> str | None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class TvContentRating(java.lang.Object):
    UNRATED: typing.ClassVar[TvContentRating] = ...
    def contains(self, rating: TvContentRating, /) -> bool: ...
    @staticmethod
    def createRating(domain: str | java.lang.String, ratingSystem: str | java.lang.String, rating: str | java.lang.String, /, *subRatings: java.lang.String) -> TvContentRating: ...
    def equals(self, obj: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def flattenToString(self) -> str: ...
    def getDomain(self) -> str: ...
    def getMainRating(self) -> str: ...
    def getRatingSystem(self) -> str: ...
    def getSubRatings(self) -> java.util.List[java.lang.String]: ...
    def hashCode(self) -> int: ...
    @staticmethod
    def unflattenFromString(ratingString: str | java.lang.String, /) -> TvContentRating: ...

class TvContract(java.lang.Object):
    ACTION_INITIALIZE_PROGRAMS: typing.ClassVar[str] = ...
    ACTION_PREVIEW_PROGRAM_ADDED_TO_WATCH_NEXT: typing.ClassVar[str] = ...
    ACTION_PREVIEW_PROGRAM_BROWSABLE_DISABLED: typing.ClassVar[str] = ...
    ACTION_REQUEST_CHANNEL_BROWSABLE: typing.ClassVar[str] = ...
    ACTION_WATCH_NEXT_PROGRAM_BROWSABLE_DISABLED: typing.ClassVar[str] = ...
    AUTHORITY: typing.ClassVar[str] = ...
    EXTRA_CHANNEL_ID: typing.ClassVar[str] = ...
    EXTRA_PREVIEW_PROGRAM_ID: typing.ClassVar[str] = ...
    EXTRA_WATCH_NEXT_PROGRAM_ID: typing.ClassVar[str] = ...
    @typing.overload
    @staticmethod
    def buildChannelLogoUri(channelId: int | java.jlong | java.lang.Long, /) -> android.net.Uri: ...
    @typing.overload
    @staticmethod
    def buildChannelLogoUri(channelUri: android.net.Uri, /) -> android.net.Uri: ...
    @staticmethod
    def buildChannelUri(channelId: int | java.jlong | java.lang.Long, /) -> android.net.Uri: ...
    @staticmethod
    def buildChannelUriForPassthroughInput(inputId: str | java.lang.String, /) -> android.net.Uri: ...
    @staticmethod
    def buildChannelsUriForInput(inputId: str | java.lang.String, /) -> android.net.Uri: ...
    @staticmethod
    def buildInputId(name: android.content.ComponentName, /) -> str: ...
    @staticmethod
    def buildPreviewProgramUri(previewProgramId: int | java.jlong | java.lang.Long, /) -> android.net.Uri: ...
    @typing.overload
    @staticmethod
    def buildPreviewProgramsUriForChannel(channelId: int | java.jlong | java.lang.Long, /) -> android.net.Uri: ...
    @typing.overload
    @staticmethod
    def buildPreviewProgramsUriForChannel(channelUri: android.net.Uri, /) -> android.net.Uri: ...
    @staticmethod
    def buildProgramUri(programId: int | java.jlong | java.lang.Long, /) -> android.net.Uri: ...
    @typing.overload
    @staticmethod
    def buildProgramsUriForChannel(channelId: int | java.jlong | java.lang.Long, /) -> android.net.Uri: ...
    @typing.overload
    @staticmethod
    def buildProgramsUriForChannel(channelUri: android.net.Uri, /) -> android.net.Uri: ...
    @typing.overload
    @staticmethod
    def buildProgramsUriForChannel(channelId: int | java.jlong | java.lang.Long, startTime: int | java.jlong | java.lang.Long, endTime: int | java.jlong | java.lang.Long, /) -> android.net.Uri: ...
    @typing.overload
    @staticmethod
    def buildProgramsUriForChannel(channelUri: android.net.Uri, startTime: int | java.jlong | java.lang.Long, endTime: int | java.jlong | java.lang.Long, /) -> android.net.Uri: ...
    @staticmethod
    def buildRecordedProgramUri(recordedProgramId: int | java.jlong | java.lang.Long, /) -> android.net.Uri: ...
    @staticmethod
    def buildWatchNextProgramUri(watchNextProgramId: int | java.jlong | java.lang.Long, /) -> android.net.Uri: ...
    @staticmethod
    def isChannelUri(uri: android.net.Uri, /) -> bool: ...
    @staticmethod
    def isChannelUriForPassthroughInput(uri: android.net.Uri, /) -> bool: ...
    @staticmethod
    def isChannelUriForTunerInput(uri: android.net.Uri, /) -> bool: ...
    @staticmethod
    def isProgramUri(uri: android.net.Uri, /) -> bool: ...
    @staticmethod
    def isRecordedProgramUri(uri: android.net.Uri, /) -> bool: ...
    @staticmethod
    def requestChannelBrowsable(context: android.content.Context, channelId: int | java.jlong | java.lang.Long, /) -> None: ...

    class WatchNextPrograms(TvContract.BaseTvColumns):
        ASPECT_RATIO_16_9: typing.ClassVar[int] = ...
        ASPECT_RATIO_1_1: typing.ClassVar[int] = ...
        ASPECT_RATIO_2_3: typing.ClassVar[int] = ...
        ASPECT_RATIO_3_2: typing.ClassVar[int] = ...
        ASPECT_RATIO_4_3: typing.ClassVar[int] = ...
        AVAILABILITY_AVAILABLE: typing.ClassVar[int] = ...
        AVAILABILITY_FREE_WITH_SUBSCRIPTION: typing.ClassVar[int] = ...
        AVAILABILITY_PAID_CONTENT: typing.ClassVar[int] = ...
        COLUMN_AUDIO_LANGUAGE: typing.ClassVar[str] = ...
        COLUMN_AUTHOR: typing.ClassVar[str] = ...
        COLUMN_AVAILABILITY: typing.ClassVar[str] = ...
        COLUMN_BROWSABLE: typing.ClassVar[str] = ...
        COLUMN_CANONICAL_GENRE: typing.ClassVar[str] = ...
        COLUMN_CONTENT_ID: typing.ClassVar[str] = ...
        COLUMN_CONTENT_RATING: typing.ClassVar[str] = ...
        COLUMN_DURATION_MILLIS: typing.ClassVar[str] = ...
        COLUMN_END_TIME_UTC_MILLIS: typing.ClassVar[str] = ...
        COLUMN_EPISODE_DISPLAY_NUMBER: typing.ClassVar[str] = ...
        COLUMN_EPISODE_TITLE: typing.ClassVar[str] = ...
        COLUMN_INTENT_URI: typing.ClassVar[str] = ...
        COLUMN_INTERACTION_COUNT: typing.ClassVar[str] = ...
        COLUMN_INTERACTION_TYPE: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_DATA: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_FLAG1: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_FLAG2: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_FLAG3: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_FLAG4: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_ID: typing.ClassVar[str] = ...
        COLUMN_ITEM_COUNT: typing.ClassVar[str] = ...
        COLUMN_LAST_ENGAGEMENT_TIME_UTC_MILLIS: typing.ClassVar[str] = ...
        COLUMN_LAST_PLAYBACK_POSITION_MILLIS: typing.ClassVar[str] = ...
        COLUMN_LIVE: typing.ClassVar[str] = ...
        COLUMN_LOGO_URI: typing.ClassVar[str] = ...
        COLUMN_LONG_DESCRIPTION: typing.ClassVar[str] = ...
        COLUMN_OFFER_PRICE: typing.ClassVar[str] = ...
        COLUMN_POSTER_ART_ASPECT_RATIO: typing.ClassVar[str] = ...
        COLUMN_POSTER_ART_URI: typing.ClassVar[str] = ...
        COLUMN_PREVIEW_VIDEO_URI: typing.ClassVar[str] = ...
        COLUMN_RELEASE_DATE: typing.ClassVar[str] = ...
        COLUMN_REVIEW_RATING: typing.ClassVar[str] = ...
        COLUMN_REVIEW_RATING_STYLE: typing.ClassVar[str] = ...
        COLUMN_SEARCHABLE: typing.ClassVar[str] = ...
        COLUMN_SEASON_DISPLAY_NUMBER: typing.ClassVar[str] = ...
        COLUMN_SEASON_TITLE: typing.ClassVar[str] = ...
        COLUMN_SERIES_ID: typing.ClassVar[str] = ...
        COLUMN_SHORT_DESCRIPTION: typing.ClassVar[str] = ...
        COLUMN_SPLIT_ID: typing.ClassVar[str] = ...
        COLUMN_STARTING_PRICE: typing.ClassVar[str] = ...
        COLUMN_START_TIME_UTC_MILLIS: typing.ClassVar[str] = ...
        COLUMN_THUMBNAIL_ASPECT_RATIO: typing.ClassVar[str] = ...
        COLUMN_THUMBNAIL_URI: typing.ClassVar[str] = ...
        COLUMN_TITLE: typing.ClassVar[str] = ...
        COLUMN_TRANSIENT: typing.ClassVar[str] = ...
        COLUMN_TYPE: typing.ClassVar[str] = ...
        COLUMN_VERSION_NUMBER: typing.ClassVar[str] = ...
        COLUMN_VIDEO_HEIGHT: typing.ClassVar[str] = ...
        COLUMN_VIDEO_WIDTH: typing.ClassVar[str] = ...
        COLUMN_WATCH_NEXT_TYPE: typing.ClassVar[str] = ...
        CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
        CONTENT_TYPE: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        INTERACTION_TYPE_FANS: typing.ClassVar[int] = ...
        INTERACTION_TYPE_FOLLOWERS: typing.ClassVar[int] = ...
        INTERACTION_TYPE_LIKES: typing.ClassVar[int] = ...
        INTERACTION_TYPE_LISTENS: typing.ClassVar[int] = ...
        INTERACTION_TYPE_THUMBS: typing.ClassVar[int] = ...
        INTERACTION_TYPE_VIEWERS: typing.ClassVar[int] = ...
        INTERACTION_TYPE_VIEWS: typing.ClassVar[int] = ...
        REVIEW_RATING_STYLE_PERCENTAGE: typing.ClassVar[int] = ...
        REVIEW_RATING_STYLE_STARS: typing.ClassVar[int] = ...
        REVIEW_RATING_STYLE_THUMBS_UP_DOWN: typing.ClassVar[int] = ...
        TYPE_ALBUM: typing.ClassVar[int] = ...
        TYPE_ARTIST: typing.ClassVar[int] = ...
        TYPE_CHANNEL: typing.ClassVar[int] = ...
        TYPE_CLIP: typing.ClassVar[int] = ...
        TYPE_EVENT: typing.ClassVar[int] = ...
        TYPE_MOVIE: typing.ClassVar[int] = ...
        TYPE_PLAYLIST: typing.ClassVar[int] = ...
        TYPE_STATION: typing.ClassVar[int] = ...
        TYPE_TRACK: typing.ClassVar[int] = ...
        TYPE_TV_EPISODE: typing.ClassVar[int] = ...
        TYPE_TV_SEASON: typing.ClassVar[int] = ...
        TYPE_TV_SERIES: typing.ClassVar[int] = ...
        WATCH_NEXT_TYPE_CONTINUE: typing.ClassVar[int] = ...
        WATCH_NEXT_TYPE_NEW: typing.ClassVar[int] = ...
        WATCH_NEXT_TYPE_NEXT: typing.ClassVar[int] = ...
        WATCH_NEXT_TYPE_WATCHLIST: typing.ClassVar[int] = ...

    class RecordedPrograms(TvContract.BaseTvColumns):
        COLUMN_AUDIO_LANGUAGE: typing.ClassVar[str] = ...
        COLUMN_BROADCAST_GENRE: typing.ClassVar[str] = ...
        COLUMN_CANONICAL_GENRE: typing.ClassVar[str] = ...
        COLUMN_CHANNEL_ID: typing.ClassVar[str] = ...
        COLUMN_CONTENT_RATING: typing.ClassVar[str] = ...
        COLUMN_END_TIME_UTC_MILLIS: typing.ClassVar[str] = ...
        COLUMN_EPISODE_DISPLAY_NUMBER: typing.ClassVar[str] = ...
        COLUMN_EPISODE_TITLE: typing.ClassVar[str] = ...
        COLUMN_INPUT_ID: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_DATA: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_FLAG1: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_FLAG2: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_FLAG3: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_FLAG4: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_ID: typing.ClassVar[str] = ...
        COLUMN_LONG_DESCRIPTION: typing.ClassVar[str] = ...
        COLUMN_MULTI_SERIES_ID: typing.ClassVar[str] = ...
        COLUMN_POSTER_ART_URI: typing.ClassVar[str] = ...
        COLUMN_RECORDING_DATA_BYTES: typing.ClassVar[str] = ...
        COLUMN_RECORDING_DATA_URI: typing.ClassVar[str] = ...
        COLUMN_RECORDING_DURATION_MILLIS: typing.ClassVar[str] = ...
        COLUMN_RECORDING_EXPIRE_TIME_UTC_MILLIS: typing.ClassVar[str] = ...
        COLUMN_REVIEW_RATING: typing.ClassVar[str] = ...
        COLUMN_REVIEW_RATING_STYLE: typing.ClassVar[str] = ...
        COLUMN_SEARCHABLE: typing.ClassVar[str] = ...
        COLUMN_SEASON_DISPLAY_NUMBER: typing.ClassVar[str] = ...
        COLUMN_SEASON_TITLE: typing.ClassVar[str] = ...
        COLUMN_SERIES_ID: typing.ClassVar[str] = ...
        COLUMN_SHORT_DESCRIPTION: typing.ClassVar[str] = ...
        COLUMN_SPLIT_ID: typing.ClassVar[str] = ...
        COLUMN_START_TIME_UTC_MILLIS: typing.ClassVar[str] = ...
        COLUMN_THUMBNAIL_URI: typing.ClassVar[str] = ...
        COLUMN_TITLE: typing.ClassVar[str] = ...
        COLUMN_VERSION_NUMBER: typing.ClassVar[str] = ...
        COLUMN_VIDEO_HEIGHT: typing.ClassVar[str] = ...
        COLUMN_VIDEO_WIDTH: typing.ClassVar[str] = ...
        CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
        CONTENT_TYPE: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        REVIEW_RATING_STYLE_PERCENTAGE: typing.ClassVar[int] = ...
        REVIEW_RATING_STYLE_STARS: typing.ClassVar[int] = ...
        REVIEW_RATING_STYLE_THUMBS_UP_DOWN: typing.ClassVar[int] = ...

    class Programs(TvContract.BaseTvColumns):
        COLUMN_AUDIO_LANGUAGE: typing.ClassVar[str] = ...
        COLUMN_BROADCAST_GENRE: typing.ClassVar[str] = ...
        COLUMN_CANONICAL_GENRE: typing.ClassVar[str] = ...
        COLUMN_CHANNEL_ID: typing.ClassVar[str] = ...
        COLUMN_CONTENT_RATING: typing.ClassVar[str] = ...
        COLUMN_END_TIME_UTC_MILLIS: typing.ClassVar[str] = ...
        COLUMN_EPISODE_DISPLAY_NUMBER: typing.ClassVar[str] = ...
        COLUMN_EPISODE_NUMBER: typing.ClassVar[str] = ...
        COLUMN_EPISODE_TITLE: typing.ClassVar[str] = ...
        COLUMN_EVENT_ID: typing.ClassVar[str] = ...
        COLUMN_GLOBAL_CONTENT_ID: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_DATA: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_FLAG1: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_FLAG2: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_FLAG3: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_FLAG4: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_ID: typing.ClassVar[str] = ...
        COLUMN_LONG_DESCRIPTION: typing.ClassVar[str] = ...
        COLUMN_MULTI_SERIES_ID: typing.ClassVar[str] = ...
        COLUMN_POSTER_ART_URI: typing.ClassVar[str] = ...
        COLUMN_RECORDING_PROHIBITED: typing.ClassVar[str] = ...
        COLUMN_REVIEW_RATING: typing.ClassVar[str] = ...
        COLUMN_REVIEW_RATING_STYLE: typing.ClassVar[str] = ...
        COLUMN_SCRAMBLED: typing.ClassVar[str] = ...
        COLUMN_SEARCHABLE: typing.ClassVar[str] = ...
        COLUMN_SEASON_DISPLAY_NUMBER: typing.ClassVar[str] = ...
        COLUMN_SEASON_NUMBER: typing.ClassVar[str] = ...
        COLUMN_SEASON_TITLE: typing.ClassVar[str] = ...
        COLUMN_SERIES_ID: typing.ClassVar[str] = ...
        COLUMN_SHORT_DESCRIPTION: typing.ClassVar[str] = ...
        COLUMN_SPLIT_ID: typing.ClassVar[str] = ...
        COLUMN_START_TIME_UTC_MILLIS: typing.ClassVar[str] = ...
        COLUMN_THUMBNAIL_URI: typing.ClassVar[str] = ...
        COLUMN_TITLE: typing.ClassVar[str] = ...
        COLUMN_VERSION_NUMBER: typing.ClassVar[str] = ...
        COLUMN_VIDEO_HEIGHT: typing.ClassVar[str] = ...
        COLUMN_VIDEO_WIDTH: typing.ClassVar[str] = ...
        CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
        CONTENT_TYPE: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        REVIEW_RATING_STYLE_PERCENTAGE: typing.ClassVar[int] = ...
        REVIEW_RATING_STYLE_STARS: typing.ClassVar[int] = ...
        REVIEW_RATING_STYLE_THUMBS_UP_DOWN: typing.ClassVar[int] = ...

        class Genres(java.lang.Object):
            ANIMAL_WILDLIFE: typing.ClassVar[str] = ...
            ARTS: typing.ClassVar[str] = ...
            COMEDY: typing.ClassVar[str] = ...
            DRAMA: typing.ClassVar[str] = ...
            EDUCATION: typing.ClassVar[str] = ...
            ENTERTAINMENT: typing.ClassVar[str] = ...
            FAMILY_KIDS: typing.ClassVar[str] = ...
            GAMING: typing.ClassVar[str] = ...
            LIFE_STYLE: typing.ClassVar[str] = ...
            MOVIES: typing.ClassVar[str] = ...
            MUSIC: typing.ClassVar[str] = ...
            NEWS: typing.ClassVar[str] = ...
            PREMIER: typing.ClassVar[str] = ...
            SHOPPING: typing.ClassVar[str] = ...
            SPORTS: typing.ClassVar[str] = ...
            TECH_SCIENCE: typing.ClassVar[str] = ...
            TRAVEL: typing.ClassVar[str] = ...
            @staticmethod
            def decode(genres: str | java.lang.String, /) -> java.chaquopy.JavaArray[java.lang.String]: ...
            @staticmethod
            def encode(*genres: java.lang.String) -> str: ...
            @staticmethod
            def isCanonical(genre: str | java.lang.String, /) -> bool: ...

    class PreviewPrograms(TvContract.BaseTvColumns):
        ASPECT_RATIO_16_9: typing.ClassVar[int] = ...
        ASPECT_RATIO_1_1: typing.ClassVar[int] = ...
        ASPECT_RATIO_2_3: typing.ClassVar[int] = ...
        ASPECT_RATIO_3_2: typing.ClassVar[int] = ...
        ASPECT_RATIO_4_3: typing.ClassVar[int] = ...
        AVAILABILITY_AVAILABLE: typing.ClassVar[int] = ...
        AVAILABILITY_FREE_WITH_SUBSCRIPTION: typing.ClassVar[int] = ...
        AVAILABILITY_PAID_CONTENT: typing.ClassVar[int] = ...
        COLUMN_AUDIO_LANGUAGE: typing.ClassVar[str] = ...
        COLUMN_AUTHOR: typing.ClassVar[str] = ...
        COLUMN_AVAILABILITY: typing.ClassVar[str] = ...
        COLUMN_BROWSABLE: typing.ClassVar[str] = ...
        COLUMN_CANONICAL_GENRE: typing.ClassVar[str] = ...
        COLUMN_CHANNEL_ID: typing.ClassVar[str] = ...
        COLUMN_CONTENT_ID: typing.ClassVar[str] = ...
        COLUMN_CONTENT_RATING: typing.ClassVar[str] = ...
        COLUMN_DURATION_MILLIS: typing.ClassVar[str] = ...
        COLUMN_END_TIME_UTC_MILLIS: typing.ClassVar[str] = ...
        COLUMN_EPISODE_DISPLAY_NUMBER: typing.ClassVar[str] = ...
        COLUMN_EPISODE_TITLE: typing.ClassVar[str] = ...
        COLUMN_INTENT_URI: typing.ClassVar[str] = ...
        COLUMN_INTERACTION_COUNT: typing.ClassVar[str] = ...
        COLUMN_INTERACTION_TYPE: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_DATA: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_FLAG1: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_FLAG2: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_FLAG3: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_FLAG4: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_ID: typing.ClassVar[str] = ...
        COLUMN_ITEM_COUNT: typing.ClassVar[str] = ...
        COLUMN_LAST_PLAYBACK_POSITION_MILLIS: typing.ClassVar[str] = ...
        COLUMN_LIVE: typing.ClassVar[str] = ...
        COLUMN_LOGO_URI: typing.ClassVar[str] = ...
        COLUMN_LONG_DESCRIPTION: typing.ClassVar[str] = ...
        COLUMN_OFFER_PRICE: typing.ClassVar[str] = ...
        COLUMN_POSTER_ART_ASPECT_RATIO: typing.ClassVar[str] = ...
        COLUMN_POSTER_ART_URI: typing.ClassVar[str] = ...
        COLUMN_PREVIEW_VIDEO_URI: typing.ClassVar[str] = ...
        COLUMN_RELEASE_DATE: typing.ClassVar[str] = ...
        COLUMN_REVIEW_RATING: typing.ClassVar[str] = ...
        COLUMN_REVIEW_RATING_STYLE: typing.ClassVar[str] = ...
        COLUMN_SEARCHABLE: typing.ClassVar[str] = ...
        COLUMN_SEASON_DISPLAY_NUMBER: typing.ClassVar[str] = ...
        COLUMN_SEASON_TITLE: typing.ClassVar[str] = ...
        COLUMN_SERIES_ID: typing.ClassVar[str] = ...
        COLUMN_SHORT_DESCRIPTION: typing.ClassVar[str] = ...
        COLUMN_SPLIT_ID: typing.ClassVar[str] = ...
        COLUMN_STARTING_PRICE: typing.ClassVar[str] = ...
        COLUMN_START_TIME_UTC_MILLIS: typing.ClassVar[str] = ...
        COLUMN_THUMBNAIL_ASPECT_RATIO: typing.ClassVar[str] = ...
        COLUMN_THUMBNAIL_URI: typing.ClassVar[str] = ...
        COLUMN_TITLE: typing.ClassVar[str] = ...
        COLUMN_TRANSIENT: typing.ClassVar[str] = ...
        COLUMN_TYPE: typing.ClassVar[str] = ...
        COLUMN_VERSION_NUMBER: typing.ClassVar[str] = ...
        COLUMN_VIDEO_HEIGHT: typing.ClassVar[str] = ...
        COLUMN_VIDEO_WIDTH: typing.ClassVar[str] = ...
        COLUMN_WEIGHT: typing.ClassVar[str] = ...
        CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
        CONTENT_TYPE: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        INTERACTION_TYPE_FANS: typing.ClassVar[int] = ...
        INTERACTION_TYPE_FOLLOWERS: typing.ClassVar[int] = ...
        INTERACTION_TYPE_LIKES: typing.ClassVar[int] = ...
        INTERACTION_TYPE_LISTENS: typing.ClassVar[int] = ...
        INTERACTION_TYPE_THUMBS: typing.ClassVar[int] = ...
        INTERACTION_TYPE_VIEWERS: typing.ClassVar[int] = ...
        INTERACTION_TYPE_VIEWS: typing.ClassVar[int] = ...
        REVIEW_RATING_STYLE_PERCENTAGE: typing.ClassVar[int] = ...
        REVIEW_RATING_STYLE_STARS: typing.ClassVar[int] = ...
        REVIEW_RATING_STYLE_THUMBS_UP_DOWN: typing.ClassVar[int] = ...
        TYPE_ALBUM: typing.ClassVar[int] = ...
        TYPE_ARTIST: typing.ClassVar[int] = ...
        TYPE_CHANNEL: typing.ClassVar[int] = ...
        TYPE_CLIP: typing.ClassVar[int] = ...
        TYPE_EVENT: typing.ClassVar[int] = ...
        TYPE_MOVIE: typing.ClassVar[int] = ...
        TYPE_PLAYLIST: typing.ClassVar[int] = ...
        TYPE_STATION: typing.ClassVar[int] = ...
        TYPE_TRACK: typing.ClassVar[int] = ...
        TYPE_TV_EPISODE: typing.ClassVar[int] = ...
        TYPE_TV_SEASON: typing.ClassVar[int] = ...
        TYPE_TV_SERIES: typing.ClassVar[int] = ...

    class Channels(TvContract.BaseTvColumns):
        BROADCAST_VISIBILITY_TYPE_INVISIBLE: typing.ClassVar[int] = ...
        BROADCAST_VISIBILITY_TYPE_NUMERIC_SELECTABLE_ONLY: typing.ClassVar[int] = ...
        BROADCAST_VISIBILITY_TYPE_VISIBLE: typing.ClassVar[int] = ...
        COLUMN_APP_LINK_COLOR: typing.ClassVar[str] = ...
        COLUMN_APP_LINK_ICON_URI: typing.ClassVar[str] = ...
        COLUMN_APP_LINK_INTENT_URI: typing.ClassVar[str] = ...
        COLUMN_APP_LINK_POSTER_ART_URI: typing.ClassVar[str] = ...
        COLUMN_APP_LINK_TEXT: typing.ClassVar[str] = ...
        COLUMN_BROADCAST_GENRE: typing.ClassVar[str] = ...
        COLUMN_BROADCAST_VISIBILITY_TYPE: typing.ClassVar[str] = ...
        COLUMN_BROWSABLE: typing.ClassVar[str] = ...
        COLUMN_CHANNEL_LIST_ID: typing.ClassVar[str] = ...
        COLUMN_DESCRIPTION: typing.ClassVar[str] = ...
        COLUMN_DISPLAY_NAME: typing.ClassVar[str] = ...
        COLUMN_DISPLAY_NUMBER: typing.ClassVar[str] = ...
        COLUMN_GLOBAL_CONTENT_ID: typing.ClassVar[str] = ...
        COLUMN_INPUT_ID: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_DATA: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_FLAG1: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_FLAG2: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_FLAG3: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_FLAG4: typing.ClassVar[str] = ...
        COLUMN_INTERNAL_PROVIDER_ID: typing.ClassVar[str] = ...
        COLUMN_LOCKED: typing.ClassVar[str] = ...
        COLUMN_NETWORK_AFFILIATION: typing.ClassVar[str] = ...
        COLUMN_ORIGINAL_NETWORK_ID: typing.ClassVar[str] = ...
        COLUMN_REMOTE_CONTROL_KEY_PRESET_NUMBER: typing.ClassVar[str] = ...
        COLUMN_SCRAMBLED: typing.ClassVar[str] = ...
        COLUMN_SEARCHABLE: typing.ClassVar[str] = ...
        COLUMN_SERVICE_ID: typing.ClassVar[str] = ...
        COLUMN_SERVICE_TYPE: typing.ClassVar[str] = ...
        COLUMN_TRANSIENT: typing.ClassVar[str] = ...
        COLUMN_TRANSPORT_STREAM_ID: typing.ClassVar[str] = ...
        COLUMN_TYPE: typing.ClassVar[str] = ...
        COLUMN_VERSION_NUMBER: typing.ClassVar[str] = ...
        COLUMN_VIDEO_FORMAT: typing.ClassVar[str] = ...
        COLUMN_VIDEO_RESOLUTION: typing.ClassVar[str] = ...
        CONTENT_ITEM_TYPE: typing.ClassVar[str] = ...
        CONTENT_TYPE: typing.ClassVar[str] = ...
        CONTENT_URI: typing.ClassVar[android.net.Uri] = ...
        SERVICE_TYPE_AUDIO: typing.ClassVar[str] = ...
        SERVICE_TYPE_AUDIO_VIDEO: typing.ClassVar[str] = ...
        SERVICE_TYPE_OTHER: typing.ClassVar[str] = ...
        TYPE_1SEG: typing.ClassVar[str] = ...
        TYPE_ATSC3_T: typing.ClassVar[str] = ...
        TYPE_ATSC_C: typing.ClassVar[str] = ...
        TYPE_ATSC_M_H: typing.ClassVar[str] = ...
        TYPE_ATSC_T: typing.ClassVar[str] = ...
        TYPE_CMMB: typing.ClassVar[str] = ...
        TYPE_DTMB: typing.ClassVar[str] = ...
        TYPE_DVB_C2: typing.ClassVar[str] = ...
        TYPE_DVB_C: typing.ClassVar[str] = ...
        TYPE_DVB_H: typing.ClassVar[str] = ...
        TYPE_DVB_S2: typing.ClassVar[str] = ...
        TYPE_DVB_S: typing.ClassVar[str] = ...
        TYPE_DVB_SH: typing.ClassVar[str] = ...
        TYPE_DVB_T2: typing.ClassVar[str] = ...
        TYPE_DVB_T: typing.ClassVar[str] = ...
        TYPE_ISDB_C: typing.ClassVar[str] = ...
        TYPE_ISDB_S3: typing.ClassVar[str] = ...
        TYPE_ISDB_S: typing.ClassVar[str] = ...
        TYPE_ISDB_T: typing.ClassVar[str] = ...
        TYPE_ISDB_TB: typing.ClassVar[str] = ...
        TYPE_NTSC: typing.ClassVar[str] = ...
        TYPE_OTHER: typing.ClassVar[str] = ...
        TYPE_PAL: typing.ClassVar[str] = ...
        TYPE_PREVIEW: typing.ClassVar[str] = ...
        TYPE_SECAM: typing.ClassVar[str] = ...
        TYPE_S_DMB: typing.ClassVar[str] = ...
        TYPE_T_DMB: typing.ClassVar[str] = ...
        VIDEO_FORMAT_1080I: typing.ClassVar[str] = ...
        VIDEO_FORMAT_1080P: typing.ClassVar[str] = ...
        VIDEO_FORMAT_2160P: typing.ClassVar[str] = ...
        VIDEO_FORMAT_240P: typing.ClassVar[str] = ...
        VIDEO_FORMAT_360P: typing.ClassVar[str] = ...
        VIDEO_FORMAT_4320P: typing.ClassVar[str] = ...
        VIDEO_FORMAT_480I: typing.ClassVar[str] = ...
        VIDEO_FORMAT_480P: typing.ClassVar[str] = ...
        VIDEO_FORMAT_576I: typing.ClassVar[str] = ...
        VIDEO_FORMAT_576P: typing.ClassVar[str] = ...
        VIDEO_FORMAT_720P: typing.ClassVar[str] = ...
        VIDEO_RESOLUTION_ED: typing.ClassVar[str] = ...
        VIDEO_RESOLUTION_FHD: typing.ClassVar[str] = ...
        VIDEO_RESOLUTION_HD: typing.ClassVar[str] = ...
        VIDEO_RESOLUTION_SD: typing.ClassVar[str] = ...
        VIDEO_RESOLUTION_UHD: typing.ClassVar[str] = ...
        @staticmethod
        def getVideoResolution(videoFormat: str | java.lang.String, /) -> str: ...

        class Logo(java.lang.Object):
            CONTENT_DIRECTORY: typing.ClassVar[str] = ...

    class BaseTvColumns(android.provider.BaseColumns):
        COLUMN_PACKAGE_NAME: typing.ClassVar[str] = ...

class TvInputInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TvInputInfo]] = ...
    EXTRA_INPUT_ID: typing.ClassVar[str] = ...
    TYPE_COMPONENT: typing.ClassVar[int] = ...
    TYPE_COMPOSITE: typing.ClassVar[int] = ...
    TYPE_DISPLAY_PORT: typing.ClassVar[int] = ...
    TYPE_DVI: typing.ClassVar[int] = ...
    TYPE_HDMI: typing.ClassVar[int] = ...
    TYPE_OTHER: typing.ClassVar[int] = ...
    TYPE_SCART: typing.ClassVar[int] = ...
    TYPE_SVIDEO: typing.ClassVar[int] = ...
    TYPE_TUNER: typing.ClassVar[int] = ...
    TYPE_VGA: typing.ClassVar[int] = ...
    def canPauseRecording(self) -> bool: ...
    def canRecord(self) -> bool: ...
    def createSettingsIntent(self) -> android.content.Intent: ...
    def createSetupIntent(self) -> android.content.Intent: ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getExtras(self) -> android.os.Bundle: ...
    def getId(self) -> str: ...
    def getParentId(self) -> str: ...
    def getServiceInfo(self) -> android.content.pm.ServiceInfo: ...
    def getTunerCount(self) -> int: ...
    def getType(self) -> int: ...
    def hashCode(self) -> int: ...
    def isHidden(self, context: android.content.Context, /) -> bool: ...
    def isPassthroughInput(self) -> bool: ...
    def loadCustomLabel(self, context: android.content.Context, /) -> java.lang.CharSequence: ...
    def loadIcon(self, context: android.content.Context, /) -> android.graphics.drawable.Drawable: ...
    def loadLabel(self, context: android.content.Context, /) -> java.lang.CharSequence: ...
    def toString(self) -> str: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, context: android.content.Context, component: android.content.ComponentName, /) -> None: ...
        def build(self) -> TvInputInfo: ...
        def setCanPauseRecording(self, canPauseRecording: bool | java.jboolean | java.lang.Boolean, /) -> TvInputInfo.Builder: ...
        def setCanRecord(self, canRecord: bool | java.jboolean | java.lang.Boolean, /) -> TvInputInfo.Builder: ...
        def setExtras(self, extras: android.os.Bundle, /) -> TvInputInfo.Builder: ...
        def setTunerCount(self, tunerCount: int | java.jint | java.lang.Integer, /) -> TvInputInfo.Builder: ...

class TvInputManager(java.lang.Object):
    ACTION_BLOCKED_RATINGS_CHANGED: typing.ClassVar[str] = ...
    ACTION_PARENTAL_CONTROLS_ENABLED_CHANGED: typing.ClassVar[str] = ...
    ACTION_QUERY_CONTENT_RATING_SYSTEMS: typing.ClassVar[str] = ...
    ACTION_SETUP_INPUTS: typing.ClassVar[str] = ...
    ACTION_VIEW_RECORDING_SCHEDULES: typing.ClassVar[str] = ...
    BROADCAST_INFO_STREAM_EVENT: typing.ClassVar[int] = ...
    BROADCAST_INFO_TYPE_COMMAND: typing.ClassVar[int] = ...
    BROADCAST_INFO_TYPE_DSMCC: typing.ClassVar[int] = ...
    BROADCAST_INFO_TYPE_PES: typing.ClassVar[int] = ...
    BROADCAST_INFO_TYPE_SECTION: typing.ClassVar[int] = ...
    BROADCAST_INFO_TYPE_TABLE: typing.ClassVar[int] = ...
    BROADCAST_INFO_TYPE_TIMELINE: typing.ClassVar[int] = ...
    BROADCAST_INFO_TYPE_TS: typing.ClassVar[int] = ...
    INPUT_STATE_CONNECTED: typing.ClassVar[int] = ...
    INPUT_STATE_CONNECTED_STANDBY: typing.ClassVar[int] = ...
    INPUT_STATE_DISCONNECTED: typing.ClassVar[int] = ...
    META_DATA_CONTENT_RATING_SYSTEMS: typing.ClassVar[str] = ...
    RECORDING_ERROR_INSUFFICIENT_SPACE: typing.ClassVar[int] = ...
    RECORDING_ERROR_RESOURCE_BUSY: typing.ClassVar[int] = ...
    RECORDING_ERROR_UNKNOWN: typing.ClassVar[int] = ...
    SESSION_DATA_KEY_AD_BUFFER: typing.ClassVar[str] = ...
    SESSION_DATA_KEY_AD_RESPONSE: typing.ClassVar[str] = ...
    SESSION_DATA_KEY_BROADCAST_INFO_RESPONSE: typing.ClassVar[str] = ...
    SESSION_DATA_KEY_CHANNEL_URI: typing.ClassVar[str] = ...
    SESSION_DATA_KEY_TRACKS: typing.ClassVar[str] = ...
    SESSION_DATA_KEY_TRACK_ID: typing.ClassVar[str] = ...
    SESSION_DATA_KEY_TRACK_TYPE: typing.ClassVar[str] = ...
    SESSION_DATA_KEY_TV_MESSAGE_TYPE: typing.ClassVar[str] = ...
    SESSION_DATA_KEY_VIDEO_UNAVAILABLE_REASON: typing.ClassVar[str] = ...
    SESSION_DATA_TYPE_AD_BUFFER_CONSUMED: typing.ClassVar[str] = ...
    SESSION_DATA_TYPE_AD_RESPONSE: typing.ClassVar[str] = ...
    SESSION_DATA_TYPE_BROADCAST_INFO_RESPONSE: typing.ClassVar[str] = ...
    SESSION_DATA_TYPE_TRACKS_CHANGED: typing.ClassVar[str] = ...
    SESSION_DATA_TYPE_TRACK_SELECTED: typing.ClassVar[str] = ...
    SESSION_DATA_TYPE_TUNED: typing.ClassVar[str] = ...
    SESSION_DATA_TYPE_TV_MESSAGE: typing.ClassVar[str] = ...
    SESSION_DATA_TYPE_VIDEO_AVAILABLE: typing.ClassVar[str] = ...
    SESSION_DATA_TYPE_VIDEO_UNAVAILABLE: typing.ClassVar[str] = ...
    SIGNAL_STRENGTH_LOST: typing.ClassVar[int] = ...
    SIGNAL_STRENGTH_STRONG: typing.ClassVar[int] = ...
    SIGNAL_STRENGTH_WEAK: typing.ClassVar[int] = ...
    TIME_SHIFT_INVALID_TIME: typing.ClassVar[int] = ...
    TIME_SHIFT_MODE_AUTO: typing.ClassVar[int] = ...
    TIME_SHIFT_MODE_LOCAL: typing.ClassVar[int] = ...
    TIME_SHIFT_MODE_NETWORK: typing.ClassVar[int] = ...
    TIME_SHIFT_MODE_OFF: typing.ClassVar[int] = ...
    TIME_SHIFT_STATUS_AVAILABLE: typing.ClassVar[int] = ...
    TIME_SHIFT_STATUS_UNAVAILABLE: typing.ClassVar[int] = ...
    TIME_SHIFT_STATUS_UNKNOWN: typing.ClassVar[int] = ...
    TIME_SHIFT_STATUS_UNSUPPORTED: typing.ClassVar[int] = ...
    TV_MESSAGE_GROUP_ID_NONE: typing.ClassVar[int] = ...
    TV_MESSAGE_KEY_GROUP_ID: typing.ClassVar[str] = ...
    TV_MESSAGE_KEY_RAW_DATA: typing.ClassVar[str] = ...
    TV_MESSAGE_KEY_STREAM_ID: typing.ClassVar[str] = ...
    TV_MESSAGE_KEY_SUBTYPE: typing.ClassVar[str] = ...
    TV_MESSAGE_SUBTYPE_CC_608E: typing.ClassVar[str] = ...
    TV_MESSAGE_SUBTYPE_WATERMARKING_A335: typing.ClassVar[str] = ...
    TV_MESSAGE_TYPE_CLOSED_CAPTION: typing.ClassVar[int] = ...
    TV_MESSAGE_TYPE_OTHER: typing.ClassVar[int] = ...
    TV_MESSAGE_TYPE_WATERMARK: typing.ClassVar[int] = ...
    VIDEO_UNAVAILABLE_REASON_AUDIO_ONLY: typing.ClassVar[int] = ...
    VIDEO_UNAVAILABLE_REASON_BUFFERING: typing.ClassVar[int] = ...
    VIDEO_UNAVAILABLE_REASON_CAS_BLACKOUT: typing.ClassVar[int] = ...
    VIDEO_UNAVAILABLE_REASON_CAS_CARD_INVALID: typing.ClassVar[int] = ...
    VIDEO_UNAVAILABLE_REASON_CAS_CARD_MUTE: typing.ClassVar[int] = ...
    VIDEO_UNAVAILABLE_REASON_CAS_INSUFFICIENT_OUTPUT_PROTECTION: typing.ClassVar[int] = ...
    VIDEO_UNAVAILABLE_REASON_CAS_LICENSE_EXPIRED: typing.ClassVar[int] = ...
    VIDEO_UNAVAILABLE_REASON_CAS_NEED_ACTIVATION: typing.ClassVar[int] = ...
    VIDEO_UNAVAILABLE_REASON_CAS_NEED_PAIRING: typing.ClassVar[int] = ...
    VIDEO_UNAVAILABLE_REASON_CAS_NO_CARD: typing.ClassVar[int] = ...
    VIDEO_UNAVAILABLE_REASON_CAS_PVR_RECORDING_NOT_ALLOWED: typing.ClassVar[int] = ...
    VIDEO_UNAVAILABLE_REASON_CAS_REBOOTING: typing.ClassVar[int] = ...
    VIDEO_UNAVAILABLE_REASON_CAS_UNKNOWN: typing.ClassVar[int] = ...
    VIDEO_UNAVAILABLE_REASON_INSUFFICIENT_RESOURCE: typing.ClassVar[int] = ...
    VIDEO_UNAVAILABLE_REASON_NOT_CONNECTED: typing.ClassVar[int] = ...
    VIDEO_UNAVAILABLE_REASON_STOPPED: typing.ClassVar[int] = ...
    VIDEO_UNAVAILABLE_REASON_TUNING: typing.ClassVar[int] = ...
    VIDEO_UNAVAILABLE_REASON_UNKNOWN: typing.ClassVar[int] = ...
    VIDEO_UNAVAILABLE_REASON_WEAK_SIGNAL: typing.ClassVar[int] = ...
    def getBlockedRatings(self) -> java.util.List[TvContentRating]: ...
    def getInputState(self, inputId: str | java.lang.String, /) -> int: ...
    def getTvInputInfo(self, inputId: str | java.lang.String, /) -> TvInputInfo | None: ...
    def getTvInputList(self) -> java.util.List[TvInputInfo]: ...
    def isParentalControlsEnabled(self) -> bool: ...
    def isRatingBlocked(self, rating: TvContentRating, /) -> bool: ...
    def registerCallback(self, callback: TvInputManager.TvInputCallback, handler: android.os.Handler, /) -> None: ...
    def unregisterCallback(self, callback: TvInputManager.TvInputCallback, /) -> None: ...
    def updateTvInputInfo(self, inputInfo: TvInputInfo, /) -> None: ...

    class TvInputCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onInputAdded(self, inputId: str | java.lang.String, /) -> None: ...
        def onInputRemoved(self, inputId: str | java.lang.String, /) -> None: ...
        def onInputStateChanged(self, inputId: str | java.lang.String, state: int | java.jint | java.lang.Integer, /) -> None: ...
        def onInputUpdated(self, inputId: str | java.lang.String, /) -> None: ...
        def onTvInputInfoUpdated(self, inputInfo: TvInputInfo, /) -> None: ...

class TvInputService(android.app.Service):
    PRIORITY_HINT_USE_CASE_TYPE_BACKGROUND: typing.ClassVar[int] = ...
    PRIORITY_HINT_USE_CASE_TYPE_LIVE: typing.ClassVar[int] = ...
    PRIORITY_HINT_USE_CASE_TYPE_PLAYBACK: typing.ClassVar[int] = ...
    PRIORITY_HINT_USE_CASE_TYPE_RECORD: typing.ClassVar[int] = ...
    PRIORITY_HINT_USE_CASE_TYPE_SCAN: typing.ClassVar[int] = ...
    SERVICE_INTERFACE: typing.ClassVar[str] = ...
    SERVICE_META_DATA: typing.ClassVar[str] = ...
    def __init__(self) -> None: ...
    def onBind(self, intent: android.content.Intent, /) -> android.os.IBinder: ...
    @typing.overload
    def onCreateRecordingSession(self, inputId: str | java.lang.String, /) -> TvInputService.RecordingSession | None: ...
    @typing.overload
    def onCreateRecordingSession(self, inputId: str | java.lang.String, sessionId: str | java.lang.String, /) -> TvInputService.RecordingSession | None: ...
    @typing.overload
    def onCreateSession(self, arg1: str | java.lang.String, /) -> TvInputService.Session | None: ...
    @typing.overload
    def onCreateSession(self, inputId: str | java.lang.String, sessionId: str | java.lang.String, /) -> TvInputService.Session | None: ...
    @typing.overload
    def onCreateSession(self, inputId: str | java.lang.String, sessionId: str | java.lang.String, tvAppAttributionSource: android.content.AttributionSource, /) -> TvInputService.Session | None: ...

    class Session(android.view.KeyEvent.Callback):
        def __init__(self, context: android.content.Context, /) -> None: ...
        def layoutSurface(self, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
        def notifyAdBufferConsumed(self, buffer: AdBuffer, /) -> None: ...
        def notifyAdResponse(self, response: AdResponse, /) -> None: ...
        def notifyAitInfoUpdated(self, aitInfo: AitInfo, /) -> None: ...
        def notifyAudioPresentationChanged(self, audioPresentations: java.util.List[android.media.AudioPresentation], /) -> None: ...
        def notifyAudioPresentationSelected(self, presentationId: int | java.jint | java.lang.Integer, programId: int | java.jint | java.lang.Integer, /) -> None: ...
        def notifyAvailableSpeeds(self, speeds: java.chaquopy.JavaArrayJFloat, /) -> None: ...
        def notifyBroadcastInfoResponse(self, response: BroadcastInfoResponse, /) -> None: ...
        def notifyChannelRetuned(self, channelUri: android.net.Uri, /) -> None: ...
        def notifyContentAllowed(self) -> None: ...
        def notifyContentBlocked(self, rating: TvContentRating, /) -> None: ...
        def notifyCueingMessageAvailability(self, available: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def notifySignalStrength(self, strength: int | java.jint | java.lang.Integer, /) -> None: ...
        def notifyTimeShiftMode(self, mode: int | java.jint | java.lang.Integer, /) -> None: ...
        def notifyTimeShiftStatusChanged(self, status: int | java.jint | java.lang.Integer, /) -> None: ...
        def notifyTrackSelected(self, type: int | java.jint | java.lang.Integer, trackId: str | java.lang.String, /) -> None: ...
        def notifyTracksChanged(self, tracks: java.util.List[TvTrackInfo], /) -> None: ...
        def notifyTuned(self, channelUri: android.net.Uri, /) -> None: ...
        def notifyTvMessage(self, type: int | java.jint | java.lang.Integer, data: android.os.Bundle, /) -> None: ...
        def notifyVideoAvailable(self) -> None: ...
        def notifyVideoFreezeUpdated(self, isFrozen: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def notifyVideoUnavailable(self, reason: int | java.jint | java.lang.Integer, /) -> None: ...
        def onAdBufferReady(self, buffer: AdBuffer, /) -> None: ...
        def onAppPrivateCommand(self, action: str | java.lang.String, data: android.os.Bundle, /) -> None: ...
        def onCreateOverlayView(self) -> android.view.View: ...
        def onGenericMotionEvent(self, event: android.view.MotionEvent, /) -> bool: ...
        def onKeyDown(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
        def onKeyLongPress(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
        def onKeyMultiple(self, keyCode: int | java.jint | java.lang.Integer, count: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
        def onKeyUp(self, keyCode: int | java.jint | java.lang.Integer, event: android.view.KeyEvent, /) -> bool: ...
        def onOverlayViewSizeChanged(self, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
        def onRelease(self) -> None: ...
        def onRemoveBroadcastInfo(self, requestId: int | java.jint | java.lang.Integer, /) -> None: ...
        def onRequestAd(self, request: AdRequest, /) -> None: ...
        def onRequestBroadcastInfo(self, request: BroadcastInfoRequest, /) -> None: ...
        def onResumePlayback(self) -> None: ...
        def onSelectAudioPresentation(self, presentationId: int | java.jint | java.lang.Integer, programId: int | java.jint | java.lang.Integer, /) -> bool: ...
        def onSelectTrack(self, type: int | java.jint | java.lang.Integer, trackId: str | java.lang.String, /) -> bool: ...
        def onSetCaptionEnabled(self, arg1: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def onSetInteractiveAppNotificationEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def onSetStreamVolume(self, arg1: float | java.jfloat | java.lang.Float, /) -> None: ...
        def onSetSurface(self, arg1: android.view.Surface, /) -> bool: ...
        def onSetTvMessageEnabled(self, type: int | java.jint | java.lang.Integer, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def onStopPlayback(self, mode: int | java.jint | java.lang.Integer, /) -> None: ...
        def onSurfaceChanged(self, format: int | java.jint | java.lang.Integer, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
        def onTimeShiftGetCurrentPosition(self) -> int: ...
        def onTimeShiftGetStartPosition(self) -> int: ...
        def onTimeShiftPause(self) -> None: ...
        def onTimeShiftPlay(self, recordedProgramUri: android.net.Uri, /) -> None: ...
        def onTimeShiftResume(self) -> None: ...
        def onTimeShiftSeekTo(self, timeMs: int | java.jlong | java.lang.Long, /) -> None: ...
        def onTimeShiftSetMode(self, mode: int | java.jint | java.lang.Integer, /) -> None: ...
        def onTimeShiftSetPlaybackParams(self, params: android.media.PlaybackParams, /) -> None: ...
        def onTouchEvent(self, event: android.view.MotionEvent, /) -> bool: ...
        def onTrackballEvent(self, event: android.view.MotionEvent, /) -> bool: ...
        @typing.overload
        def onTune(self, arg1: android.net.Uri, /) -> bool: ...
        @typing.overload
        def onTune(self, channelUri: android.net.Uri, params: android.os.Bundle, /) -> bool: ...
        def onTvAdSessionData(self, type: str | java.lang.String, data: android.os.Bundle, /) -> None: ...
        def onTvMessage(self, type: int | java.jint | java.lang.Integer, data: android.os.Bundle, /) -> None: ...
        def onUnblockContent(self, unblockedRating: TvContentRating, /) -> None: ...
        def sendTvInputSessionData(self, type: str | java.lang.String, data: android.os.Bundle, /) -> None: ...
        def setOverlayViewEnabled(self, enable: bool | java.jboolean | java.lang.Boolean, /) -> None: ...

    class RecordingSession(java.lang.Object):
        def __init__(self, context: android.content.Context, /) -> None: ...
        def notifyError(self, error: int | java.jint | java.lang.Integer, /) -> None: ...
        def notifyRecordingStopped(self, recordedProgramUri: android.net.Uri, /) -> None: ...
        def notifyTuned(self, channelUri: android.net.Uri, /) -> None: ...
        def onAppPrivateCommand(self, action: str | java.lang.String, data: android.os.Bundle, /) -> None: ...
        def onPauseRecording(self, params: android.os.Bundle, /) -> None: ...
        def onRelease(self) -> None: ...
        def onResumeRecording(self, params: android.os.Bundle, /) -> None: ...
        @typing.overload
        def onStartRecording(self, arg1: android.net.Uri, /) -> None: ...
        @typing.overload
        def onStartRecording(self, programUri: android.net.Uri, params: android.os.Bundle, /) -> None: ...
        def onStopRecording(self) -> None: ...
        @typing.overload
        def onTune(self, arg1: android.net.Uri, /) -> None: ...
        @typing.overload
        def onTune(self, channelUri: android.net.Uri, params: android.os.Bundle, /) -> None: ...

    class HardwareSession(TvInputService.Session):
        def __init__(self, context: android.content.Context, /) -> None: ...
        def getHardwareInputId(self) -> str: ...
        def onHardwareVideoAvailable(self) -> None: ...
        def onHardwareVideoUnavailable(self, reason: int | java.jint | java.lang.Integer, /) -> None: ...
        def onSetSurface(self, surface: android.view.Surface, /) -> bool: ...

class TvRecordingClient(java.lang.Object):
    def __init__(self, context: android.content.Context, tag: str | java.lang.String, callback: TvRecordingClient.RecordingCallback, handler: android.os.Handler, /) -> None: ...
    @typing.overload
    def pauseRecording(self) -> None: ...
    @typing.overload
    def pauseRecording(self, params: android.os.Bundle, /) -> None: ...
    def release(self) -> None: ...
    @typing.overload
    def resumeRecording(self) -> None: ...
    @typing.overload
    def resumeRecording(self, params: android.os.Bundle, /) -> None: ...
    def sendAppPrivateCommand(self, action: str | java.lang.String, data: android.os.Bundle, /) -> None: ...
    def setTvInteractiveAppView(self, view: android.media.tv.interactive.TvInteractiveAppView, recordingId: str | java.lang.String, /) -> None: ...
    @typing.overload
    def startRecording(self, programUri: android.net.Uri, /) -> None: ...
    @typing.overload
    def startRecording(self, programUri: android.net.Uri, params: android.os.Bundle, /) -> None: ...
    def stopRecording(self) -> None: ...
    @typing.overload
    def tune(self, inputId: str | java.lang.String, channelUri: android.net.Uri, /) -> None: ...
    @typing.overload
    def tune(self, inputId: str | java.lang.String, channelUri: android.net.Uri, params: android.os.Bundle, /) -> None: ...

    class RecordingCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onConnectionFailed(self, inputId: str | java.lang.String, /) -> None: ...
        def onDisconnected(self, inputId: str | java.lang.String, /) -> None: ...
        def onError(self, error: int | java.jint | java.lang.Integer, /) -> None: ...
        def onRecordingStopped(self, recordedProgramUri: android.net.Uri, /) -> None: ...
        def onTuned(self, channelUri: android.net.Uri, /) -> None: ...

class TvRecordingInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TvRecordingInfo]] = ...
    FRIDAY: typing.ClassVar[int] = ...
    MONDAY: typing.ClassVar[int] = ...
    RECORDING_ALL: typing.ClassVar[int] = ...
    RECORDING_IN_PROGRESS: typing.ClassVar[int] = ...
    RECORDING_SCHEDULED: typing.ClassVar[int] = ...
    SATURDAY: typing.ClassVar[int] = ...
    SUNDAY: typing.ClassVar[int] = ...
    THURSDAY: typing.ClassVar[int] = ...
    TUESDAY: typing.ClassVar[int] = ...
    WEDNESDAY: typing.ClassVar[int] = ...
    def __init__(self, recordingId: str | java.lang.String, startPadding: int | java.jlong | java.lang.Long, endPadding: int | java.jlong | java.lang.Long, repeatDays: int | java.jint | java.lang.Integer, name: str | java.lang.String, description: str | java.lang.String, scheduledStartTime: int | java.jlong | java.lang.Long, scheduledDuration: int | java.jlong | java.lang.Long, channelUri: android.net.Uri, programUri: android.net.Uri, contentRatings: java.util.List[TvContentRating], recordingUri: android.net.Uri, recordingStartTime: int | java.jlong | java.lang.Long, recordingDuration: int | java.jlong | java.lang.Long, /) -> None: ...
    def describeContents(self) -> int: ...
    def getChannelUri(self) -> android.net.Uri: ...
    def getContentRatings(self) -> java.util.List[TvContentRating]: ...
    def getDescription(self) -> str: ...
    def getEndPaddingMillis(self) -> int: ...
    def getName(self) -> str: ...
    def getProgramUri(self) -> android.net.Uri | None: ...
    def getRecordingDurationMillis(self) -> int: ...
    def getRecordingId(self) -> str: ...
    def getRecordingStartTimeMillis(self) -> int: ...
    def getRecordingUri(self) -> android.net.Uri | None: ...
    def getRepeatDays(self) -> int: ...
    def getScheduledDurationMillis(self) -> int: ...
    def getScheduledStartTimeMillis(self) -> int: ...
    def getStartPaddingMillis(self) -> int: ...
    def setDescription(self, description: str | java.lang.String, /) -> None: ...
    def setName(self, name: str | java.lang.String, /) -> None: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

class TvTrackInfo(android.os.Parcelable):
    CREATOR: typing.ClassVar[android.os.Parcelable.Creator[TvTrackInfo]] = ...
    TYPE_AUDIO: typing.ClassVar[int] = ...
    TYPE_SUBTITLE: typing.ClassVar[int] = ...
    TYPE_VIDEO: typing.ClassVar[int] = ...
    def describeContents(self) -> int: ...
    def equals(self, o: java.lang.Object | int | bool | float | str, /) -> bool: ...
    def getAudioChannelCount(self) -> int: ...
    def getAudioSampleRate(self) -> int: ...
    def getDescription(self) -> java.lang.CharSequence: ...
    def getEncoding(self) -> str | None: ...
    def getExtra(self) -> android.os.Bundle: ...
    def getId(self) -> str: ...
    def getLanguage(self) -> str: ...
    def getType(self) -> int: ...
    def getVideoActiveFormatDescription(self) -> int: ...
    def getVideoFrameRate(self) -> float: ...
    def getVideoHeight(self) -> int: ...
    def getVideoPixelAspectRatio(self) -> float: ...
    def getVideoWidth(self) -> int: ...
    def hashCode(self) -> int: ...
    def isAudioDescription(self) -> bool: ...
    def isEncrypted(self) -> bool: ...
    def isHardOfHearing(self) -> bool: ...
    def isSpokenSubtitle(self) -> bool: ...
    def writeToParcel(self, dest: android.os.Parcel, flags: int | java.jint | java.lang.Integer, /) -> None: ...

    class Builder(java.lang.Object):
        def __init__(self, type: int | java.jint | java.lang.Integer, id: str | java.lang.String, /) -> None: ...
        def build(self) -> TvTrackInfo: ...
        def setAudioChannelCount(self, audioChannelCount: int | java.jint | java.lang.Integer, /) -> TvTrackInfo.Builder: ...
        def setAudioDescription(self, audioDescription: bool | java.jboolean | java.lang.Boolean, /) -> TvTrackInfo.Builder: ...
        def setAudioSampleRate(self, audioSampleRate: int | java.jint | java.lang.Integer, /) -> TvTrackInfo.Builder: ...
        def setDescription(self, description: java.lang.CharSequence, /) -> TvTrackInfo.Builder: ...
        def setEncoding(self, encoding: str | java.lang.String, /) -> TvTrackInfo.Builder: ...
        def setEncrypted(self, encrypted: bool | java.jboolean | java.lang.Boolean, /) -> TvTrackInfo.Builder: ...
        def setExtra(self, extra: android.os.Bundle, /) -> TvTrackInfo.Builder: ...
        def setHardOfHearing(self, hardOfHearing: bool | java.jboolean | java.lang.Boolean, /) -> TvTrackInfo.Builder: ...
        def setLanguage(self, language: str | java.lang.String, /) -> TvTrackInfo.Builder: ...
        def setSpokenSubtitle(self, spokenSubtitle: bool | java.jboolean | java.lang.Boolean, /) -> TvTrackInfo.Builder: ...
        def setVideoActiveFormatDescription(self, videoActiveFormatDescription: int | java.jbyte | java.lang.Byte, /) -> TvTrackInfo.Builder: ...
        def setVideoFrameRate(self, videoFrameRate: float | java.jfloat | java.lang.Float, /) -> TvTrackInfo.Builder: ...
        def setVideoHeight(self, videoHeight: int | java.jint | java.lang.Integer, /) -> TvTrackInfo.Builder: ...
        def setVideoPixelAspectRatio(self, videoPixelAspectRatio: float | java.jfloat | java.lang.Float, /) -> TvTrackInfo.Builder: ...
        def setVideoWidth(self, videoWidth: int | java.jint | java.lang.Integer, /) -> TvTrackInfo.Builder: ...

class TvView(android.view.ViewGroup):
    @typing.overload
    def __init__(self, context: android.content.Context, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, /) -> None: ...
    @typing.overload
    def __init__(self, context: android.content.Context, attrs: android.util.AttributeSet, defStyleAttr: int | java.jint | java.lang.Integer, /) -> None: ...
    def dispatchDraw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def dispatchGenericMotionEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def dispatchKeyEvent(self, event: android.view.KeyEvent, /) -> bool: ...
    def dispatchTouchEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def dispatchTrackballEvent(self, event: android.view.MotionEvent, /) -> bool: ...
    def dispatchUnhandledInputEvent(self, event: android.view.InputEvent, /) -> bool: ...
    def dispatchWindowFocusChanged(self, hasFocus: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def draw(self, canvas: android.graphics.Canvas, /) -> None: ...
    def gatherTransparentRegion(self, region: android.graphics.Region, /) -> bool: ...
    def getAudioPresentations(self) -> java.util.List[android.media.AudioPresentation]: ...
    def getSelectedTrack(self, type: int | java.jint | java.lang.Integer, /) -> str: ...
    def getTracks(self, type: int | java.jint | java.lang.Integer, /) -> java.util.List[TvTrackInfo]: ...
    def onAttachedToWindow(self) -> None: ...
    def onDetachedFromWindow(self) -> None: ...
    def onLayout(self, changed: bool | java.jboolean | java.lang.Boolean, left: int | java.jint | java.lang.Integer, top: int | java.jint | java.lang.Integer, right: int | java.jint | java.lang.Integer, bottom: int | java.jint | java.lang.Integer, /) -> None: ...
    def onMeasure(self, widthMeasureSpec: int | java.jint | java.lang.Integer, heightMeasureSpec: int | java.jint | java.lang.Integer, /) -> None: ...
    def onUnhandledInputEvent(self, event: android.view.InputEvent, /) -> bool: ...
    def onVisibilityChanged(self, changedView: android.view.View, visibility: int | java.jint | java.lang.Integer, /) -> None: ...
    def overrideTvAppAttributionSource(self, tvAppAttributionSource: android.content.AttributionSource, /) -> None: ...
    def reset(self) -> None: ...
    def resumePlayback(self) -> None: ...
    def selectAudioPresentation(self, presentationId: int | java.jint | java.lang.Integer, programId: int | java.jint | java.lang.Integer, /) -> None: ...
    def selectTrack(self, type: int | java.jint | java.lang.Integer, trackId: str | java.lang.String, /) -> None: ...
    def sendAppPrivateCommand(self, action: str | java.lang.String, data: android.os.Bundle, /) -> None: ...
    def setCallback(self, callback: TvView.TvInputCallback, /) -> None: ...
    def setCaptionEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setInteractiveAppNotificationEnabled(self, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setOnUnhandledInputEventListener(self, listener: TvView.OnUnhandledInputEventListener, /) -> None: ...
    def setStreamVolume(self, volume: float | java.jfloat | java.lang.Float, /) -> None: ...
    def setTimeShiftPositionCallback(self, callback: TvView.TimeShiftPositionCallback, /) -> None: ...
    def setTvMessageEnabled(self, type: int | java.jint | java.lang.Integer, enabled: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setVideoFrozen(self, isFrozen: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setZOrderMediaOverlay(self, isMediaOverlay: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def setZOrderOnTop(self, onTop: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
    def stopPlayback(self, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    def timeShiftPause(self) -> None: ...
    def timeShiftPlay(self, inputId: str | java.lang.String, recordedProgramUri: android.net.Uri, /) -> None: ...
    def timeShiftResume(self) -> None: ...
    def timeShiftSeekTo(self, timeMs: int | java.jlong | java.lang.Long, /) -> None: ...
    def timeShiftSetMode(self, mode: int | java.jint | java.lang.Integer, /) -> None: ...
    def timeShiftSetPlaybackParams(self, params: android.media.PlaybackParams, /) -> None: ...
    @typing.overload
    def tune(self, inputId: str | java.lang.String, channelUri: android.net.Uri, /) -> None: ...
    @typing.overload
    def tune(self, inputId: str | java.lang.String, channelUri: android.net.Uri, params: android.os.Bundle, /) -> None: ...

    class TvInputCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onAitInfoUpdated(self, inputId: str | java.lang.String, aitInfo: AitInfo, /) -> None: ...
        def onAudioPresentationSelected(self, inputId: str | java.lang.String, presentationId: int | java.jint | java.lang.Integer, programId: int | java.jint | java.lang.Integer, /) -> None: ...
        def onAudioPresentationsChanged(self, inputId: str | java.lang.String, audioPresentations: java.util.List[android.media.AudioPresentation], /) -> None: ...
        def onAvailableSpeeds(self, inputId: str | java.lang.String, speeds: java.chaquopy.JavaArrayJFloat, /) -> None: ...
        def onChannelRetuned(self, inputId: str | java.lang.String, channelUri: android.net.Uri, /) -> None: ...
        def onConnectionFailed(self, inputId: str | java.lang.String, /) -> None: ...
        def onContentAllowed(self, inputId: str | java.lang.String, /) -> None: ...
        def onContentBlocked(self, inputId: str | java.lang.String, rating: TvContentRating, /) -> None: ...
        def onCueingMessageAvailability(self, inputId: str | java.lang.String, available: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def onDisconnected(self, inputId: str | java.lang.String, /) -> None: ...
        def onSignalStrengthUpdated(self, inputId: str | java.lang.String, strength: int | java.jint | java.lang.Integer, /) -> None: ...
        def onTimeShiftMode(self, inputId: str | java.lang.String, mode: int | java.jint | java.lang.Integer, /) -> None: ...
        def onTimeShiftStatusChanged(self, inputId: str | java.lang.String, status: int | java.jint | java.lang.Integer, /) -> None: ...
        def onTrackSelected(self, inputId: str | java.lang.String, type: int | java.jint | java.lang.Integer, trackId: str | java.lang.String, /) -> None: ...
        def onTracksChanged(self, inputId: str | java.lang.String, tracks: java.util.List[TvTrackInfo], /) -> None: ...
        def onTuned(self, inputId: str | java.lang.String, channelUri: android.net.Uri, /) -> None: ...
        def onTvMessage(self, inputId: str | java.lang.String, type: int | java.jint | java.lang.Integer, data: android.os.Bundle, /) -> None: ...
        def onVideoAvailable(self, inputId: str | java.lang.String, /) -> None: ...
        def onVideoFreezeUpdated(self, inputId: str | java.lang.String, isFrozen: bool | java.jboolean | java.lang.Boolean, /) -> None: ...
        def onVideoSizeChanged(self, inputId: str | java.lang.String, width: int | java.jint | java.lang.Integer, height: int | java.jint | java.lang.Integer, /) -> None: ...
        def onVideoUnavailable(self, inputId: str | java.lang.String, reason: int | java.jint | java.lang.Integer, /) -> None: ...

    class TimeShiftPositionCallback(java.lang.Object):
        def __init__(self) -> None: ...
        def onTimeShiftCurrentPositionChanged(self, inputId: str | java.lang.String, timeMs: int | java.jlong | java.lang.Long, /) -> None: ...
        def onTimeShiftStartPositionChanged(self, inputId: str | java.lang.String, timeMs: int | java.jlong | java.lang.Long, /) -> None: ...

    class OnUnhandledInputEventListener(java.lang.Object):
        def onUnhandledInputEvent(self, arg1: android.view.InputEvent, /) -> bool: ...
